# generated by datamodel-codegen:
#   filename:  enums/forecast_range_unit.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class ForecastRangeUnit(Enum):
    spend = 'spend'
    reach_freq = 'reach_freq'
    weekly = 'weekly'
    daily = 'daily'
    clicks = 'clicks'
    conversions = 'conversions'
