# generated by datamodel-codegen:
#   filename:  enums/universal_macro.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class UniversalMacro(Enum):
    MEDIA_BUY_ID = 'MEDIA_BUY_ID'
    PACKAGE_ID = 'PACKAGE_ID'
    CREATIVE_ID = 'CREATIVE_ID'
    CACHEBUSTER = 'CACHEBUSTER'
    TIMESTAMP = 'TIMESTAMP'
    CLICK_URL = 'CLICK_URL'
    GDPR = 'GDPR'
    GDPR_CONSENT = 'GDPR_CONSENT'
    US_PRIVACY = 'US_PRIVACY'
    GPP_STRING = 'GPP_STRING'
    GPP_SID = 'GPP_SID'
    IP_ADDRESS = 'IP_ADDRESS'
    LIMIT_AD_TRACKING = 'LIMIT_AD_TRACKING'
    DEVICE_TYPE = 'DEVICE_TYPE'
    OS = 'OS'
    OS_VERSION = 'OS_VERSION'
    DEVICE_MAKE = 'DEVICE_MAKE'
    DEVICE_MODEL = 'DEVICE_MODEL'
    USER_AGENT = 'USER_AGENT'
    APP_BUNDLE = 'APP_BUNDLE'
    APP_NAME = 'APP_NAME'
    COUNTRY = 'COUNTRY'
    REGION = 'REGION'
    CITY = 'CITY'
    ZIP = 'ZIP'
    DMA = 'DMA'
    LAT = 'LAT'
    LONG = 'LONG'
    DEVICE_ID = 'DEVICE_ID'
    DEVICE_ID_TYPE = 'DEVICE_ID_TYPE'
    DOMAIN = 'DOMAIN'
    PAGE_URL = 'PAGE_URL'
    REFERRER = 'REFERRER'
    KEYWORDS = 'KEYWORDS'
    PLACEMENT_ID = 'PLACEMENT_ID'
    FOLD_POSITION = 'FOLD_POSITION'
    AD_WIDTH = 'AD_WIDTH'
    AD_HEIGHT = 'AD_HEIGHT'
    VIDEO_ID = 'VIDEO_ID'
    VIDEO_TITLE = 'VIDEO_TITLE'
    VIDEO_DURATION = 'VIDEO_DURATION'
    VIDEO_CATEGORY = 'VIDEO_CATEGORY'
    CONTENT_GENRE = 'CONTENT_GENRE'
    CONTENT_RATING = 'CONTENT_RATING'
    PLAYER_WIDTH = 'PLAYER_WIDTH'
    PLAYER_HEIGHT = 'PLAYER_HEIGHT'
    POD_POSITION = 'POD_POSITION'
    POD_SIZE = 'POD_SIZE'
    AD_BREAK_ID = 'AD_BREAK_ID'
    STATION_ID = 'STATION_ID'
    SHOW_NAME = 'SHOW_NAME'
    EPISODE_ID = 'EPISODE_ID'
    AUDIO_DURATION = 'AUDIO_DURATION'
    AXEM = 'AXEM'
    CATALOG_ID = 'CATALOG_ID'
    SKU = 'SKU'
    GTIN = 'GTIN'
    OFFERING_ID = 'OFFERING_ID'
    JOB_ID = 'JOB_ID'
    HOTEL_ID = 'HOTEL_ID'
    FLIGHT_ID = 'FLIGHT_ID'
    VEHICLE_ID = 'VEHICLE_ID'
    LISTING_ID = 'LISTING_ID'
    STORE_ID = 'STORE_ID'
    PROGRAM_ID = 'PROGRAM_ID'
    DESTINATION_ID = 'DESTINATION_ID'
    CREATIVE_VARIANT_ID = 'CREATIVE_VARIANT_ID'
    APP_ITEM_ID = 'APP_ITEM_ID'
