# generated by datamodel-codegen:
#   filename:  core/placement.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from . import format_id


class Placement(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    description: Annotated[
        str | None, Field(description='Detailed description of where and how the placement appears')
    ] = None
    format_ids: Annotated[
        list[format_id.FormatId] | None,
        Field(
            description='Format IDs supported by this specific placement. Can include: (1) concrete format_ids (fixed dimensions), (2) template format_ids without parameters (accepts any dimensions/duration), or (3) parameterized format_ids (specific dimension/duration constraints).',
            min_length=1,
        ),
    ] = None
    name: Annotated[
        str,
        Field(
            description="Human-readable name for the placement (e.g., 'Homepage Banner', 'Article Sidebar')"
        ),
    ]
    placement_id: Annotated[
        str, Field(description='Unique identifier for the placement within the product')
    ]
