# generated by datamodel-codegen:
#   filename:  enums/wcag_level.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class WcagLevel(Enum):
    A = 'A'
    AA = 'AA'
    AAA = 'AAA'
