# generated by datamodel-codegen:
#   filename:  property/property_feature.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class PropertyFeature(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    feature_id: Annotated[str, Field(description='Identifier for the feature being assessed')]
    source: Annotated[
        str | None,
        Field(description='Source of the feature data (e.g., app_store_privacy_label, tcf_string)'),
    ] = None
    value: Annotated[str, Field(description='The feature value')]
