# generated by datamodel-codegen:
#   filename:  core/brand_id.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from pydantic import Field, RootModel


class BrandId(RootModel[str]):
    root: Annotated[
        str,
        Field(
            description='Identifier for a brand within a house portfolio. Must be lowercase alphanumeric with underscores only. The house chooses this identifier.',
            examples=['tide', 'cheerios', 'air_jordan', 'nike', 'pampers'],
            pattern='^[a-z0-9_]+$',
            title='Brand ID',
        ),
    ]
