# generated by datamodel-codegen:
#   filename:  enums/uid_type.json
#   timestamp: 2026-02-27T02:10:10+00:00

from __future__ import annotations

from enum import Enum


class UidType(Enum):
    rampid = 'rampid'
    id5 = 'id5'
    uid2 = 'uid2'
    euid = 'euid'
    pairid = 'pairid'
    maid = 'maid'
    other = 'other'
