# generated by datamodel-codegen:
#   filename:  sponsored_intelligence/si_ui_element.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum
from typing import Annotated, Any

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class Type(Enum):
    text = 'text'
    link = 'link'
    image = 'image'
    product_card = 'product_card'
    carousel = 'carousel'
    action_button = 'action_button'
    app_handoff = 'app_handoff'
    integration_actions = 'integration_actions'


class SiUiElement(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    data: Annotated[dict[str, Any] | None, Field(description='Component-specific data')] = None
    type: Annotated[Type, Field(description='Component type')]
