# generated by datamodel-codegen:
#   filename:  enums/format_id_parameter.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class FormatIdParameter(Enum):
    dimensions = 'dimensions'
    duration = 'duration'
