# generated by datamodel-codegen:
#   filename:  sponsored_intelligence/si_get_offering_request.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import ext as ext_1


class SiGetOfferingRequest(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    context: Annotated[
        str | None,
        Field(
            description="Optional natural language context about user intent for personalized results (e.g., 'mens size 14 near Cincinnati'). Must be anonymous - no PII."
        ),
    ] = None
    ext: ext_1.ExtensionObject | None = None
    include_products: Annotated[
        bool | None, Field(description='Whether to include matching products in the response')
    ] = False
    offering_id: Annotated[
        str, Field(description='Offering identifier from the catalog to get details for')
    ]
    product_limit: Annotated[
        int | None, Field(description='Maximum number of matching products to return', ge=1, le=50)
    ] = 5
