# generated by datamodel-codegen:
#   filename:  enums/pacing.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class Pacing(Enum):
    even = 'even'
    asap = 'asap'
    front_loaded = 'front_loaded'
