# generated by datamodel-codegen:
#   filename:  enums/geo_level.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class GeographicTargetingLevel(Enum):
    country = 'country'
    region = 'region'
    metro = 'metro'
    postal_area = 'postal_area'
