# generated by datamodel-codegen:
#   filename:  core/assets/catalog_asset.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from ..catalog import Catalog


class CatalogAsset(Catalog):
    pass
