# generated by datamodel-codegen:
#   filename:  property/delete_property_list_request.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import context as context_1
from ..core import ext as ext_1


class DeletePropertyListRequest(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    context: context_1.ContextObject | None = None
    ext: ext_1.ExtensionObject | None = None
    list_id: Annotated[str, Field(description='ID of the property list to delete')]
