# generated by datamodel-codegen:
#   filename:  sponsored_intelligence/si_initiate_session_response.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import error
from ..core import ext as ext_1
from . import si_capabilities, si_ui_element


class Response(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    message: Annotated[str | None, Field(description='Conversational message from brand agent')] = (
        None
    )
    ui_elements: Annotated[
        list[si_ui_element.SiUiElement] | None, Field(description='Visual components to render')
    ] = None


class SiInitiateSessionResponse(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    errors: Annotated[
        list[error.Error] | None, Field(description='Errors during session initiation')
    ] = None
    ext: ext_1.ExtensionObject | None = None
    negotiated_capabilities: Annotated[
        si_capabilities.SiCapabilities | None,
        Field(description='Intersection of brand and host capabilities for this session'),
    ] = None
    response: Annotated[Response | None, Field(description="Brand agent's initial response")] = None
    session_id: Annotated[
        str, Field(description='Unique session identifier for subsequent messages')
    ]
