# generated by datamodel-codegen:
#   filename:  enums/forecast_method.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class ForecastMethod(Enum):
    estimate = 'estimate'
    modeled = 'modeled'
    guaranteed = 'guaranteed'
