# generated by datamodel-codegen:
#   filename:  content_standards/create_content_standards_response.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import Field, RootModel

from ..core import context as context_1
from ..core import error
from ..core import ext as ext_1


class CreateContentStandardsResponse1(AdCPBaseModel):
    context: context_1.ContextObject | None = None
    ext: ext_1.ExtensionObject | None = None
    standards_id: Annotated[
        str, Field(description='Unique identifier for the created standards configuration')
    ]


class CreateContentStandardsResponse2(AdCPBaseModel):
    conflicting_standards_id: Annotated[
        str | None,
        Field(
            description='If the error is a scope conflict, the ID of the existing standards that conflict'
        ),
    ] = None
    context: context_1.ContextObject | None = None
    errors: list[error.Error]
    ext: ext_1.ExtensionObject | None = None


class CreateContentStandardsResponse(
    RootModel[CreateContentStandardsResponse1 | CreateContentStandardsResponse2]
):
    root: Annotated[
        CreateContentStandardsResponse1 | CreateContentStandardsResponse2,
        Field(
            description='Response payload for creating a content standards configuration',
            title='Create Content Standards Response',
        ),
    ]
