# generated by datamodel-codegen:
#   filename:  enums/landing_page_requirement.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class LandingPageRequirement(Enum):
    any = 'any'
    retailer_site_only = 'retailer_site_only'
    must_include_retailer = 'must_include_retailer'
