# generated by datamodel-codegen:
#   filename:  property/get_property_list_request.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import context as context_1
from ..core import ext as ext_1


class Pagination(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    cursor: Annotated[
        str | None,
        Field(description='Opaque cursor from a previous response to fetch the next page'),
    ] = None
    max_results: Annotated[
        int | None,
        Field(description='Maximum number of identifiers to return per page', ge=1, le=10000),
    ] = 1000


class GetPropertyListRequest(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    context: context_1.ContextObject | None = None
    ext: ext_1.ExtensionObject | None = None
    list_id: Annotated[str, Field(description='ID of the property list to retrieve')]
    pagination: Annotated[
        Pagination | None,
        Field(
            description='Pagination parameters. Uses higher limits than standard pagination because property lists can contain tens of thousands of identifiers.'
        ),
    ] = None
    resolve: Annotated[
        bool | None,
        Field(
            description='Whether to apply filters and return resolved identifiers (default: true)'
        ),
    ] = True
