# generated by datamodel-codegen:
#   filename:  core/requirements/text_asset_requirements.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class TextAssetRequirements(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    character_pattern: Annotated[
        str | None,
        Field(
            description="Regex pattern defining allowed characters (e.g., '^[a-zA-Z0-9 .,!?-]+$')"
        ),
    ] = None
    max_length: Annotated[int | None, Field(description='Maximum character length', ge=1)] = None
    max_lines: Annotated[int | None, Field(description='Maximum number of lines', ge=1)] = None
    min_length: Annotated[int | None, Field(description='Minimum character length', ge=0)] = None
    min_lines: Annotated[int | None, Field(description='Minimum number of lines', ge=1)] = None
    prohibited_terms: Annotated[
        list[str] | None, Field(description='List of prohibited words or phrases')
    ] = None
