# generated by datamodel-codegen:
#   filename:  enums/action_source.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class ActionSource(Enum):
    website = 'website'
    app = 'app'
    offline = 'offline'
    phone_call = 'phone_call'
    chat = 'chat'
    email = 'email'
    in_store = 'in_store'
    system_generated = 'system_generated'
    other = 'other'
