# generated by datamodel-codegen:
#   filename:  media_buy/get_products_async_response_input_required.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum
from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import context as context_1
from ..core import ext as ext_1
from ..core import product


class Reason(Enum):
    CLARIFICATION_NEEDED = 'CLARIFICATION_NEEDED'
    BUDGET_REQUIRED = 'BUDGET_REQUIRED'


class GetProductsInputRequired(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    context: context_1.ContextObject | None = None
    ext: ext_1.ExtensionObject | None = None
    partial_results: Annotated[
        list[product.Product] | None,
        Field(description='Partial product results that may help inform the clarification'),
    ] = None
    reason: Annotated[
        Reason | None, Field(description='Reason code indicating why input is needed')
    ] = None
    suggestions: Annotated[
        list[str] | None, Field(description='Suggested values or options for the required input')
    ] = None
