# generated by datamodel-codegen:
#   filename:  media_buy/sync_creatives_async_response_input_required.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum
from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import context as context_1
from ..core import ext as ext_1


class Reason(Enum):
    APPROVAL_REQUIRED = 'APPROVAL_REQUIRED'
    ASSET_CONFIRMATION = 'ASSET_CONFIRMATION'
    FORMAT_CLARIFICATION = 'FORMAT_CLARIFICATION'


class SyncCreativesInputRequired(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    context: context_1.ContextObject | None = None
    ext: ext_1.ExtensionObject | None = None
    reason: Annotated[
        Reason | None, Field(description='Reason code indicating why buyer input is needed')
    ] = None
