# generated by datamodel-codegen:
#   filename:  enums/daast_version.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class DaastVersion(Enum):
    field_1_0 = '1.0'
    field_1_1 = '1.1'
