# generated by datamodel-codegen:
#   filename:  content_standards/get_content_standards_request.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import Field

from ..core import context as context_1
from ..core import ext as ext_1


class GetContentStandardsRequest(AdCPBaseModel):
    context: context_1.ContextObject | None = None
    ext: ext_1.ExtensionObject | None = None
    standards_id: Annotated[
        str, Field(description='Identifier for the standards configuration to retrieve')
    ]
