# generated by datamodel-codegen:
#   filename:  core/context.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict


class ContextObject(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
