# generated by datamodel-codegen:
#   filename:  core/datetime_range.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import AwareDatetime, ConfigDict, Field


class DatetimeRange(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    end: Annotated[AwareDatetime, Field(description='End timestamp (inclusive), ISO 8601')]
    start: Annotated[AwareDatetime, Field(description='Start timestamp (inclusive), ISO 8601')]
