# generated by datamodel-codegen:
#   filename:  enums/age_verification_method.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class AgeVerificationMethod(Enum):
    facial_age_estimation = 'facial_age_estimation'
    id_document = 'id_document'
    digital_id = 'digital_id'
    credit_card = 'credit_card'
    world_id = 'world_id'
