# generated by datamodel-codegen:
#   filename:  content_standards/calibrate_content_request.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import Field

from . import artifact as artifact_1


class CalibrateContentRequest(AdCPBaseModel):
    artifact: Annotated[artifact_1.Artifact, Field(description='Artifact to evaluate')]
    standards_id: Annotated[str, Field(description='Standards configuration to calibrate against')]
