# generated by datamodel-codegen:
#   filename:  enums/metro_system.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class MetroAreaSystem(Enum):
    nielsen_dma = 'nielsen_dma'
    uk_itl1 = 'uk_itl1'
    uk_itl2 = 'uk_itl2'
    eurostat_nuts2 = 'eurostat_nuts2'
    custom = 'custom'
