# generated by datamodel-codegen:
#   filename:  enums/signal_catalog_type.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class SignalCatalogType(Enum):
    marketplace = 'marketplace'
    custom = 'custom'
    owned = 'owned'
