# generated by datamodel-codegen:
#   filename:  enums/distance_unit.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class DistanceUnit(Enum):
    km = 'km'
    mi = 'mi'
    m = 'm'
