# generated by datamodel-codegen:
#   filename:  enums/preview_output_format.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class PreviewOutputFormat(Enum):
    url = 'url'
    html = 'html'
