# generated by datamodel-codegen:
#   filename:  enums/history_entry_type.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class HistoryEntryType(Enum):
    request = 'request'
    response = 'response'
