# generated by datamodel-codegen:
#   filename:  enums/transport_mode.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class TransportMode(Enum):
    walking = 'walking'
    cycling = 'cycling'
    driving = 'driving'
    public_transport = 'public_transport'
