"""AdCP Type System.

All AdCP types exported from a single location.
Users should import from here or directly from adcp.

    from adcp.types import Product, CreativeFilters
    from adcp import Product, CreativeFilters

IMPORTANT: Never import directly from adcp.types.generated_poc or
adcp.types._generated. These are internal modules regenerated from
upstream schemas. Only import from adcp.types (this module) or adcp.

Type Coercion:
    Request types accept flexible input for developer ergonomics:

    - Enum fields accept string values:
        ListCreativeFormatsRequest(type="video")  # Works!
        ListCreativeFormatsRequest(type=FormatCategory.video)  # Also works

    - Context fields accept dicts:
        GetProductsRequest(context={"key": "value"})  # Works!

    - FieldModel lists accept strings:
        ListCreativesRequest(fields=["creative_id", "name"])  # Works!

    See adcp.types._ergonomic for implementation details.
"""

from __future__ import annotations

# Apply type coercion to generated types (must be imported before other types)
from adcp.types import (
    _ergonomic,  # noqa: F401
    aliases,  # noqa: F401
)

# Also make submodules available for advanced use
from adcp.types import _generated as generated  # noqa: F401

# Import all types from generated code
# V3 Protocol Discovery types
# V3 Content Standards types
# V3 Sponsored Intelligence types
# V3 Governance (Property Lists) types
# Re-export webhook payload type for webhook handling
from adcp.types._generated import (
    A2UiComponent,
    A2UiSurface,
    Account,
    AccountReference,
    AccountScope,
    ActivateSignalRequest,
    ActivateSignalResponse,
    AggregatedTotals,
    Artifact,
    ArtifactWebhookPayload,
    Asset,
    AssetContentType,
    AssetSelectors,
    AssignedPackage,
    Assignments,
    AudienceSource,
    AudioAsset,
    Authentication,
    AuthenticationScheme,
    AuthorizedAgents,
    AvailableMetric,
    BrandManifest,
    BrandReference,
    BuildCreativeRequest,
    BuildCreativeResponse,
    BuyingMode,
    ByCatalogItemItem,
    ByPackageItem,
    CalibrateContentRequest,
    CalibrateContentResponse,
    Catalog,
    CatalogAction,
    CatalogFieldBinding,
    CatalogFieldBinding1,
    CatalogFieldMapping,
    CatalogItemStatus,
    CatalogRequirements,
    CatalogType,
    CoBrandingRequirement,
    Colors,
    Contact,
    ContentIdType,
    ContentStandards,
    ContextObject,
    Country,
    CpaPricingOption,
    CpcPricingOption,
    CpcvPricingOption,
    CpmPricingOption,
    CppPricingOption,
    CpvPricingOption,
    CreateContentStandardsRequest,
    CreateContentStandardsResponse,
    CreateMediaBuyRequest,
    CreateMediaBuyResponse,
    CreatePropertyListRequest,
    CreatePropertyListResponse,
    Creative,
    CreativeAction,
    CreativeAgent,
    CreativeAgentCapability,
    CreativeApproval,
    CreativeApprovalStatus,
    CreativeAsset,
    CreativeAssignment,
    CreativeFilters,
    CreativeManifest,
    CreativePolicy,
    CreativeStatus,
    CreativeVariant,
    CssAsset,
    DaastTrackingEvent,
    DaastVersion,
    DailyBreakdownItem,
    DateRange,
    DatetimeRange,
    DayOfWeek,
    DaypartTarget,
    DeletePropertyListRequest,
    DeletePropertyListResponse,
    DeliverTo,
    DeliveryForecast,
    DeliveryMeasurement,
    DeliveryMetrics,
    DeliveryStatus,
    DeliveryType,
    DemographicSystem,
    DevicePlatform,
    DeviceType,
    DimensionUnit,
    Disclaimer,
    DoohMetrics,
    Duration,
    Error,
    ErrorCode,
    EventType,
    ExtensionObject,
    FeedbackSource,
    FeedFormat,
    Field1,
    FieldModel,
    FlatRatePricingOption,
    Fonts,
    ForecastableMetric,
    ForecastMethod,
    ForecastPoint,
    ForecastRange,
    ForecastRangeUnit,
    Format,
    FormatCard,
    FormatCardDetailed,
    FormatCategory,
    FormatId,
    FormatIdParameter,
    FrequencyCap,
    FrequencyCapScope,
    GeoCountry,
    GeoMetro,
    GeoPostalArea,
    GeoRegion,
    GetAccountFinancialsRequest,
    GetAccountFinancialsResponse,
    GetAdcpCapabilitiesRequest,
    GetAdcpCapabilitiesResponse,
    GetContentStandardsRequest,
    GetContentStandardsResponse,
    GetCreativeDeliveryRequest,
    GetCreativeDeliveryResponse,
    GetCreativeFeaturesRequest,
    GetCreativeFeaturesResponse,
    GetMediaBuyArtifactsRequest,
    GetMediaBuyArtifactsResponse,
    GetMediaBuyDeliveryRequest,
    GetMediaBuyDeliveryResponse,
    GetMediaBuysRequest,
    GetMediaBuysResponse,
    GetProductsRequest,
    GetProductsResponse,
    GetPropertyListRequest,
    GetPropertyListResponse,
    GetSignalsRequest,
    GetSignalsResponse,
    Gtin,
    HtmlAsset,
    HttpMethod,
    Identifier,
    ImageAsset,
    Input,
    JavascriptAsset,
    JavascriptModuleType,
    LandingPageRequirement,
    ListAccountsRequest,
    ListAccountsResponse,
    ListAuthorizedPropertiesRequest,
    ListAuthorizedPropertiesResponse,
    ListContentStandardsRequest,
    ListContentStandardsResponse,
    ListCreativeFormatsRequest,
    ListCreativeFormatsResponse,
    ListCreativesRequest,
    ListCreativesResponse,
    ListPropertyListsRequest,
    ListPropertyListsResponse,
    LogEventRequest,
    LogEventResponse,
    Logo,
    MarkdownFlavor,
    McpWebhookPayload,
    MeasurementPeriod,
    MediaBuy,
    MediaBuyDelivery,
    MediaBuyPackage,
    MediaBuyStatus,
    MediaChannel,
    Metadata,
    MetricType,
    NotificationType,
    Offering,
    OfferingAssetConstraint,
    OfferingAssetGroup,
    OptimizationGoal,
    OutcomeMeasurement,
    Overlay,
    Pacing,
    PackageRequest,
    PackageStatus,
    PackageUpdate,
    Pagination,
    PaginationRequest,
    Parameters,
    Performance,
    PerformanceFeedback,
    Placement,
    Preview,
    PreviewCreativeRequest,
    PreviewCreativeResponse,
    PreviewOutputFormat,
    PreviewRender,
    PriceGuidance,
    Pricing,
    PricingModel,
    PrimaryCountry,
    Product,
    ProductCard,
    ProductCardDetailed,
    ProductCatalog,
    ProductFilters,
    PromotedOfferings,
    PromotedOfferingsAssetRequirements,
    PromotedOfferingsRequirement,
    PromotedProducts,
    Property,
    PropertyIdentifierTypes,
    PropertyList,
    PropertyListChangedWebhook,
    PropertyListFilters,
    PropertyListReference,
    PropertyType,
    Proposal,
    ProtocolEnvelope,
    ProtocolResponse,
    ProvidePerformanceFeedbackRequest,
    ProvidePerformanceFeedbackResponse,
    PublisherDomain,
    PublisherIdentifierTypes,
    PushNotificationConfig,
    QuartileData,
    QuerySummary,
    ReachUnit,
    Refine,
    ReportingCapabilities,
    ReportingFrequency,
    ReportingPeriod,
    ReportingWebhook,
    ReportUsageRequest,
    ReportUsageResponse,
    Request,
    Response,
    Responsive,
    Results,
    Security,
    SiCapabilities,
    SiGetOfferingRequest,
    SiGetOfferingResponse,
    Signal,
    SignalCatalogType,
    SignalFilters,
    SignalPricing,
    SignalPricingOption,
    SiIdentity,
    SiInitiateSessionRequest,
    SiInitiateSessionResponse,
    SiSendMessageRequest,
    SiSendMessageResponse,
    SiTerminateSessionRequest,
    SiTerminateSessionResponse,
    SiUiElement,
    Snapshot,
    SnapshotUnavailableReason,
    Sort,
    SortApplied,
    SortDirection,
    StatusSummary,
    SyncAccountsRequest,
    SyncAccountsResponse,
    SyncAudiencesRequest,
    SyncAudiencesResponse,
    SyncCatalogsInputRequired,
    SyncCatalogsRequest,
    SyncCatalogsResponse,
    SyncCatalogsSubmitted,
    SyncCatalogsWorking,
    SyncCreativesRequest,
    SyncCreativesResponse,
    SyncEventSourcesRequest,
    SyncEventSourcesResponse,
    Tags,
    TargetingOverlay,
    TaskType,
    TextAsset,
    TimeBasedPricingOption,
    TimeUnit,
    Totals,
    Transform,
    UpdateContentStandardsRequest,
    UpdateContentStandardsResponse,
    UpdateFrequency,
    UpdateMediaBuyRequest,
    UpdateMediaBuyResponse,
    UpdatePropertyListRequest,
    UpdatePropertyListResponse,
    UrlAsset,
    UrlAssetType,
    ValidateContentDeliveryRequest,
    ValidateContentDeliveryResponse,
    ValidationMode,
    VastTrackingEvent,
    VastVersion,
    VcpmPricingOption,
    VenueBreakdownItem,
    VideoAsset,
    ViewThreshold,
    WcagLevel,
    WebhookAsset,
    WebhookResponseType,
)
from adcp.types._generated import TaskStatus as GeneratedTaskStatus
from adcp.types._generated import _PackageFromPackage as Package

# Import semantic aliases for discriminated unions
from adcp.types.aliases import (
    AccountReferenceById,
    AccountReferenceByNaturalKey,
    ActivateSignalErrorResponse,
    ActivateSignalSuccessResponse,
    AgentDeployment,
    AgentDestination,
    AuthorizedAgent,
    AuthorizedAgentsByInlineProperties,
    AuthorizedAgentsByPropertyId,
    AuthorizedAgentsByPropertyTag,
    AuthorizedAgentsByPublisherProperties,
    AuthorizedAgentsBySignalId,
    AuthorizedAgentsBySignalTag,
    BothPreviewRender,
    BuildCreativeErrorResponse,
    BuildCreativeSuccessResponse,
    CalibrateContentErrorResponse,
    CalibrateContentSuccessResponse,
    CatalogGroupBinding,
    ConsentBasis,
    CpmSignalPricingOption,
    CreateContentStandardsErrorResponse,
    CreateContentStandardsSuccessResponse,
    CreateMediaBuyErrorResponse,
    CreateMediaBuySuccessResponse,
    Deployment,
    Destination,
    FlatFeeSignalPricingOption,
    GetAccountFinancialsErrorResponse,
    GetAccountFinancialsSuccessResponse,
    GetContentStandardsErrorResponse,
    GetContentStandardsSuccessResponse,
    GetCreativeDeliveryByBuyerRefRequest,
    GetCreativeDeliveryByCreativeRequest,
    GetCreativeDeliveryByMediaBuyRequest,
    GetCreativeFeaturesErrorResponse,
    GetCreativeFeaturesSuccessResponse,
    GetMediaBuyArtifactsErrorResponse,
    GetMediaBuyArtifactsSuccessResponse,
    GetProductsBriefRequest,
    GetProductsRefineRequest,
    GetProductsWholesaleRequest,
    GetSignalsDiscoveryRequest,
    GetSignalsLookupRequest,
    HtmlPreviewRender,
    InlineDaastAsset,
    InlineVastAsset,
    KeyValueActivationKey,
    ListContentStandardsErrorResponse,
    ListContentStandardsSuccessResponse,
    LogEventErrorResponse,
    LogEventSuccessResponse,
    MediaBuyDeliveryStatus,
    MediaSubAsset,
    PercentOfMediaSignalPricingOption,
    PlatformDeployment,
    PlatformDestination,
    PreviewCreativeBatchRequest,
    PreviewCreativeBatchResponse,
    PreviewCreativeSingleRequest,
    PreviewCreativeSingleResponse,
    PreviewCreativeVariantRequest,
    PreviewCreativeVariantResponse,
    PricingOption,
    PropertyId,
    PropertyTag,
    ProvidePerformanceFeedbackByBuyerRefRequest,
    ProvidePerformanceFeedbackByMediaBuyRequest,
    ProvidePerformanceFeedbackErrorResponse,
    ProvidePerformanceFeedbackSuccessResponse,
    PublisherProperties,
    PublisherPropertiesAll,
    PublisherPropertiesById,
    PublisherPropertiesByTag,
    SegmentIdActivationKey,
    SiSendActionResponseRequest,
    SiSendTextMessageRequest,
    SyncAccountsErrorResponse,
    SyncAccountsSuccessResponse,
    SyncAudiencesAudience,
    SyncAudiencesErrorResponse,
    SyncAudiencesSuccessResponse,
    SyncCatalogResult,
    SyncCatalogsErrorResponse,
    SyncCatalogsSuccessResponse,
    SyncCreativeResult,
    SyncCreativesErrorResponse,
    SyncCreativesSuccessResponse,
    SyncEventSourcesErrorResponse,
    SyncEventSourcesSuccessResponse,
    TextSubAsset,
    UpdateContentStandardsErrorResponse,
    UpdateContentStandardsSuccessResponse,
    UpdateMediaBuyErrorResponse,
    UpdateMediaBuyPackagesRequest,
    UpdateMediaBuyPropertiesRequest,
    UpdateMediaBuySuccessResponse,
    UrlDaastAsset,
    UrlPreviewRender,
    UrlVastAsset,
    ValidateContentDeliveryErrorResponse,
    ValidateContentDeliverySuccessResponse,
)

# Re-export core types (not in generated, but part of public API)
# Note: We don't import TaskStatus here to avoid shadowing GeneratedTaskStatus
# Users should import TaskStatus from adcp.types.core directly if they need the core enum
from adcp.types.core import (
    AgentConfig,
    Member,
    Protocol,
    ResolvedBrand,
    ResolvedProperty,
    TaskResult,
    WebhookMetadata,
)

# Status: _generated picks invoice status (get_account_financials_response) due to
# alphabetical module sort. Import the delivery status variant directly for backward compat.
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_response import (  # noqa: E501
    Status,
)

# Semantic aliases for auto-generated field enum names
ListCreativesField = Field1

# Backward compatibility aliases
AssetType = AssetContentType  # Use AssetContentType instead
Measurement = OutcomeMeasurement  # Renamed upstream to OutcomeMeasurement

# Pricing type renames: upstream merged auction/fixed variants into single types
CpmAuctionPricingOption = CpmPricingOption
CpmFixedRatePricingOption = CpmPricingOption
VcpmAuctionPricingOption = VcpmPricingOption
VcpmFixedRatePricingOption = VcpmPricingOption

# Activation key schema change: property_id/property_tag → segment_id/key_value
PropertyIdActivationKey = SegmentIdActivationKey
PropertyTagActivationKey = KeyValueActivationKey

# Preview alias renames: format/manifest → single/batch/variant discriminator
PreviewCreativeFormatRequest = PreviewCreativeSingleRequest
PreviewCreativeManifestRequest = PreviewCreativeBatchRequest
PreviewCreativeStaticResponse = PreviewCreativeSingleResponse
PreviewCreativeInteractiveResponse = PreviewCreativeBatchResponse

# Schema renames from filter ref split (v1.0.0)
Action = CreativeAction
Capability = CreativeAgentCapability
CoBranding = CoBrandingRequirement
FormatType = FormatCategory
LandingPage = LandingPageRequirement
Method = HttpMethod
ModuleType = JavascriptModuleType
TrackingEvent = VastTrackingEvent  # Split into DaastTrackingEvent and VastTrackingEvent
Unit = DimensionUnit
OutputFormat = PreviewOutputFormat
ResponseType = WebhookResponseType
Scheme = AuthenticationScheme
SignalType = SignalCatalogType
UrlType = UrlAssetType
AvailableReportingFrequency = ReportingFrequency

__all__ = [
    # A2UI types
    "A2UiComponent",
    "A2UiSurface",
    # Account types
    "Account",
    "AccountReference",
    "AccountReferenceById",
    "AccountReferenceByNaturalKey",
    "AccountScope",
    "GetAccountFinancialsRequest",
    "GetAccountFinancialsResponse",
    "ListAccountsRequest",
    "ListAccountsResponse",
    "ReportUsageRequest",
    "ReportUsageResponse",
    "SyncAccountsRequest",
    "SyncAccountsResponse",
    # Request/Response types
    "ActivateSignalRequest",
    "ActivateSignalResponse",
    "CreativeAction",
    "AggregatedTotals",
    "BuildCreativeRequest",
    "BuildCreativeResponse",
    "ByCatalogItemItem",
    "ByPackageItem",
    "CreateMediaBuyRequest",
    "CreateMediaBuyResponse",
    "DailyBreakdownItem",
    "GetMediaBuyDeliveryRequest",
    "GetMediaBuyDeliveryResponse",
    "GetMediaBuysRequest",
    "GetMediaBuysResponse",
    "GetProductsRequest",
    "GetProductsResponse",
    "GetSignalsRequest",
    "GetSignalsResponse",
    "ListCreativeFormatsRequest",
    "ListCreativeFormatsResponse",
    "ListCreativesRequest",
    "ListCreativesResponse",
    "MediaBuyDelivery",
    "PreviewCreativeRequest",
    "PreviewCreativeResponse",
    "ProtocolEnvelope",
    "ProtocolResponse",
    "ProvidePerformanceFeedbackRequest",
    "ProvidePerformanceFeedbackResponse",
    "QuerySummary",
    "Refine",
    "SortApplied",
    "StatusSummary",
    "SyncCatalogsInputRequired",
    "SyncCatalogsRequest",
    "SyncCatalogsResponse",
    "SyncCatalogsSubmitted",
    "SyncCatalogsWorking",
    "SyncAudiencesAudience",
    "SyncAudiencesRequest",
    "SyncAudiencesResponse",
    "ConsentBasis",
    "SyncCreativesRequest",
    "SyncCreativesResponse",
    # Event & Source Operations
    "LogEventRequest",
    "LogEventResponse",
    "SyncEventSourcesRequest",
    "SyncEventSourcesResponse",
    "Totals",
    "UpdateMediaBuyRequest",
    "UpdateMediaBuyResponse",
    # V3 Protocol Discovery
    "GetAdcpCapabilitiesRequest",
    "GetAdcpCapabilitiesResponse",
    # Creative Delivery
    "GetCreativeDeliveryRequest",
    "GetCreativeDeliveryResponse",
    # Creative Features
    "GetCreativeFeaturesRequest",
    "GetCreativeFeaturesResponse",
    # Forecasting types
    "DayOfWeek",
    "DaypartTarget",
    "DeliveryForecast",
    "DemographicSystem",
    "ForecastMethod",
    "ForecastPoint",
    "ForecastRange",
    "ForecastRangeUnit",
    "ForecastableMetric",
    "ReachUnit",
    # V3 Content Standards
    "Artifact",
    "ArtifactWebhookPayload",
    "CalibrateContentRequest",
    "CalibrateContentResponse",
    "ContentStandards",
    "CreateContentStandardsRequest",
    "CreateContentStandardsResponse",
    "GetContentStandardsRequest",
    "GetContentStandardsResponse",
    "GetMediaBuyArtifactsRequest",
    "GetMediaBuyArtifactsResponse",
    "ListContentStandardsRequest",
    "ListContentStandardsResponse",
    "UpdateContentStandardsRequest",
    "UpdateContentStandardsResponse",
    "ValidateContentDeliveryRequest",
    "ValidateContentDeliveryResponse",
    # V3 Sponsored Intelligence
    "SiCapabilities",
    "SiGetOfferingRequest",
    "SiGetOfferingResponse",
    "SiIdentity",
    "SiInitiateSessionRequest",
    "SiInitiateSessionResponse",
    "SiSendMessageRequest",
    "SiSendMessageResponse",
    "SiTerminateSessionRequest",
    "SiTerminateSessionResponse",
    "SiUiElement",
    # V3 Governance (Property Lists)
    "CreatePropertyListRequest",
    "CreatePropertyListResponse",
    "DeletePropertyListRequest",
    "DeletePropertyListResponse",
    "GetPropertyListRequest",
    "GetPropertyListResponse",
    "ListPropertyListsRequest",
    "ListPropertyListsResponse",
    "PropertyList",
    "PropertyListChangedWebhook",
    "PropertyListFilters",
    "PropertyListReference",
    "UpdatePropertyListRequest",
    "UpdatePropertyListResponse",
    # Catalog types
    "Catalog",
    "CatalogAction",
    "CatalogFieldBinding",
    "CatalogFieldBinding1",
    "CatalogGroupBinding",
    "CatalogFieldMapping",
    "CatalogItemStatus",
    "CatalogRequirements",
    "CatalogType",
    "ContentIdType",
    "Gtin",
    "OfferingAssetConstraint",
    "OfferingAssetGroup",
    # Domain types
    "Asset",
    "AssetSelectors",
    "AssetContentType",
    "AssetType",  # Deprecated
    "AudienceSource",
    "BrandReference",
    "BuyingMode",
    "ContextObject",
    "DateRange",
    "DatetimeRange",
    "Duration",
    "FormatCategory",
    "AssignedPackage",
    "Assignments",
    "BrandManifest",
    "CreativeAgentCapability",
    "CoBrandingRequirement",
    "Colors",
    "Contact",
    "Creative",
    "CreativeAgent",
    "CreativeApproval",
    "CreativeApprovalStatus",
    "CreativeAsset",
    "CreativeAssignment",
    "CreativeFilters",
    "CreativeManifest",
    "CreativePolicy",
    "CreativeVariant",
    "DevicePlatform",
    "DeviceType",
    "DeliveryMeasurement",
    "DeliveryMetrics",
    "DeliveryStatus",
    "Disclaimer",
    "DoohMetrics",
    "Error",
    "ErrorCode",
    "EventType",
    "ExtensionObject",
    "FeedFormat",
    "Fonts",
    "Format",
    "FormatCard",
    "FormatCardDetailed",
    "FormatId",
    "FormatIdParameter",
    "Identifier",
    "Input",
    "LandingPageRequirement",
    "Logo",
    "ListCreativesField",
    "MediaBuy",
    "MediaBuyPackage",
    "MediaChannel",
    "Metadata",
    "Offering",
    "OptimizationGoal",
    "OutcomeMeasurement",
    "Overlay",
    "Package",
    "PackageRequest",
    "PackageUpdate",
    "Parameters",
    "Performance",
    "PerformanceFeedback",
    "Placement",
    "Preview",
    "PreviewRender",
    "Pricing",
    "Product",
    "ProductCard",
    "Proposal",
    "ProductCardDetailed",
    "ProductCatalog",
    "ProductFilters",
    "PromotedOfferings",
    "PromotedOfferingsAssetRequirements",
    "PromotedOfferingsRequirement",
    "PromotedProducts",
    "Property",
    "QuartileData",
    "Request",
    "Response",
    "Results",
    "Signal",
    "SignalFilters",
    "SignalPricing",
    "SignalPricingOption",
    "CpmSignalPricingOption",
    "FlatFeeSignalPricingOption",
    "PercentOfMediaSignalPricingOption",
    "Snapshot",
    "SnapshotUnavailableReason",
    "Tags",
    "TargetingOverlay",
    "Transform",
    "VenueBreakdownItem",
    # Pricing types
    "CpaPricingOption",
    "CpcPricingOption",
    "CpcvPricingOption",
    "CpmPricingOption",
    "CppPricingOption",
    "CpvPricingOption",
    "FlatRatePricingOption",
    "PriceGuidance",
    "TimeBasedPricingOption",
    "TimeUnit",
    "VcpmPricingOption",
    # Status enums & simple types
    "SignalCatalogType",
    "Country",
    "CreativeStatus",
    "DaastVersion",
    "DeliverTo",
    "DeliveryType",
    "SortDirection",
    "FeedbackSource",
    "FieldModel",
    "FrequencyCap",
    "FrequencyCapScope",
    "GeoCountry",
    "GeoMetro",
    "GeoPostalArea",
    "GeoRegion",
    "MarkdownFlavor",
    "MeasurementPeriod",
    "MediaBuyStatus",
    "HttpMethod",
    "MetricType",
    "JavascriptModuleType",
    "NotificationType",
    "PreviewOutputFormat",
    "Pacing",
    "Pagination",
    "PaginationRequest",
    "PricingModel",
    "PrimaryCountry",
    "PropertyIdentifierTypes",
    "PropertyType",
    "PublisherDomain",
    "PublisherIdentifierTypes",
    "WebhookResponseType",
    "Responsive",
    "Sort",
    "Status",
    "TaskType",
    "DaastTrackingEvent",
    "VastTrackingEvent",
    "DimensionUnit",
    "UpdateFrequency",
    "UrlAssetType",
    "ValidationMode",
    "VastVersion",
    "ViewThreshold",
    "WcagLevel",
    # Configuration & infrastructure types
    "Authentication",
    "AuthorizedAgents",
    "AvailableMetric",
    "PushNotificationConfig",
    "ReportingCapabilities",
    "ReportingFrequency",
    "ReportingPeriod",
    "ReportingWebhook",
    "AuthenticationScheme",
    "Security",
    # Assets
    "AudioAsset",
    "CssAsset",
    "HtmlAsset",
    "ImageAsset",
    "JavascriptAsset",
    "TextAsset",
    "UrlAsset",
    "VideoAsset",
    "WebhookAsset",
    # Core types
    "AgentConfig",
    "Member",
    "Protocol",
    "ResolvedBrand",
    "ResolvedProperty",
    "TaskResult",
    "WebhookMetadata",
    # Webhook types
    "McpWebhookPayload",
    # Semantic aliases for discriminated unions
    "ActivateSignalErrorResponse",
    "ActivateSignalSuccessResponse",
    "AgentDeployment",
    "AgentDestination",
    "AuthorizedAgent",
    "AuthorizedAgentsByInlineProperties",
    "AuthorizedAgentsByPropertyId",
    "AuthorizedAgentsByPropertyTag",
    "AuthorizedAgentsByPublisherProperties",
    "AuthorizedAgentsBySignalId",
    "AuthorizedAgentsBySignalTag",
    "BothPreviewRender",
    "BuildCreativeErrorResponse",
    "BuildCreativeSuccessResponse",
    "CalibrateContentErrorResponse",
    "CalibrateContentSuccessResponse",
    "CreateContentStandardsErrorResponse",
    "CreateContentStandardsSuccessResponse",
    "CreateMediaBuyErrorResponse",
    "CreateMediaBuySuccessResponse",
    "Deployment",
    "Destination",
    "GetContentStandardsErrorResponse",
    "GetContentStandardsSuccessResponse",
    "GetCreativeDeliveryByBuyerRefRequest",
    "GetCreativeDeliveryByCreativeRequest",
    "GetCreativeDeliveryByMediaBuyRequest",
    "GetMediaBuyArtifactsErrorResponse",
    "GetMediaBuyArtifactsSuccessResponse",
    "GetProductsBriefRequest",
    "GetProductsRefineRequest",
    "GetProductsWholesaleRequest",
    "GetSignalsDiscoveryRequest",
    "GetSignalsLookupRequest",
    "HtmlPreviewRender",
    "InlineDaastAsset",
    "InlineVastAsset",
    "ListContentStandardsErrorResponse",
    "ListContentStandardsSuccessResponse",
    "LogEventErrorResponse",
    "LogEventSuccessResponse",
    "MediaSubAsset",
    "PlatformDeployment",
    "PlatformDestination",
    "PreviewCreativeBatchRequest",
    "PreviewCreativeBatchResponse",
    "PreviewCreativeSingleRequest",
    "PreviewCreativeSingleResponse",
    "PreviewCreativeVariantRequest",
    "PreviewCreativeVariantResponse",
    "PricingOption",
    "PropertyId",
    "PropertyTag",
    "ProvidePerformanceFeedbackByBuyerRefRequest",
    "ProvidePerformanceFeedbackByMediaBuyRequest",
    "ProvidePerformanceFeedbackErrorResponse",
    "ProvidePerformanceFeedbackSuccessResponse",
    "PublisherProperties",
    "PublisherPropertiesAll",
    "PublisherPropertiesById",
    "PublisherPropertiesByTag",
    "SegmentIdActivationKey",
    "KeyValueActivationKey",
    "SiSendTextMessageRequest",
    "SiSendActionResponseRequest",
    "SyncAccountsErrorResponse",
    "SyncAccountsSuccessResponse",
    "SyncCatalogResult",
    "SyncCatalogsErrorResponse",
    "SyncCatalogsSuccessResponse",
    "SyncCreativesErrorResponse",
    "SyncCreativesSuccessResponse",
    "SyncCreativeResult",
    "SyncEventSourcesErrorResponse",
    "SyncEventSourcesSuccessResponse",
    "TextSubAsset",
    "UpdateContentStandardsErrorResponse",
    "UpdateContentStandardsSuccessResponse",
    "UpdateMediaBuyErrorResponse",
    "UpdateMediaBuyPackagesRequest",
    "UpdateMediaBuyPropertiesRequest",
    "UpdateMediaBuySuccessResponse",
    "UrlDaastAsset",
    "UrlPreviewRender",
    "UrlVastAsset",
    "ValidateContentDeliveryErrorResponse",
    "ValidateContentDeliverySuccessResponse",
    # Account financials responses
    "GetAccountFinancialsErrorResponse",
    "GetAccountFinancialsSuccessResponse",
    # Audiences responses
    "MediaBuyDeliveryStatus",
    "SyncAudiencesErrorResponse",
    "SyncAudiencesSuccessResponse",
    # Creative features responses
    "GetCreativeFeaturesErrorResponse",
    "GetCreativeFeaturesSuccessResponse",
    # Internal/special exports
    "GeneratedTaskStatus",
    # Backward compatibility aliases (deprecated)
    "Action",
    "Capability",
    "CoBranding",
    "FormatType",
    "LandingPage",
    "Measurement",
    "Method",
    "ModuleType",
    "TrackingEvent",
    "Unit",
    "OutputFormat",
    "ResponseType",
    "Scheme",
    "SignalType",
    "UrlType",
    "AvailableReportingFrequency",
    # Backward compat: pricing type renames (auction/fixed merged into single types)
    "CpmAuctionPricingOption",
    "CpmFixedRatePricingOption",
    "VcpmAuctionPricingOption",
    "VcpmFixedRatePricingOption",
    # Backward compat: activation key schema change
    "PropertyIdActivationKey",
    "PropertyTagActivationKey",
    # Backward compat: preview alias renames
    "PreviewCreativeFormatRequest",
    "PreviewCreativeManifestRequest",
    "PreviewCreativeStaticResponse",
    "PreviewCreativeInteractiveResponse",
    # Backward compat: types removed from upstream schemas
    "ListAuthorizedPropertiesRequest",
    "ListAuthorizedPropertiesResponse",
    "PackageStatus",
    # Submodules for advanced use:
    "generated",
    "aliases",
]
