# generated by datamodel-codegen:
#   filename:  enums/digital_source_type.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from enum import Enum


class DigitalSourceType(Enum):
    digital_capture = 'digital_capture'
    digital_creation = 'digital_creation'
    trained_algorithmic_media = 'trained_algorithmic_media'
    composite_with_trained_algorithmic_media = 'composite_with_trained_algorithmic_media'
    algorithmic_media = 'algorithmic_media'
    composite_capture = 'composite_capture'
    composite_synthetic = 'composite_synthetic'
    human_edits = 'human_edits'
    data_driven_media = 'data_driven_media'
