# generated by datamodel-codegen:
#   filename:  enums/disclosure_position.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from enum import Enum


class DisclosurePosition(Enum):
    prominent = 'prominent'
    footer = 'footer'
    audio = 'audio'
    subtitle = 'subtitle'
    overlay = 'overlay'
    end_card = 'end_card'
    pre_roll = 'pre_roll'
    companion = 'companion'
