# generated by datamodel-codegen:
#   filename:  core/requirements/css_asset_requirements.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class CssAssetRequirements(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    max_file_size_kb: Annotated[
        int | None, Field(description='Maximum file size in kilobytes', ge=1)
    ] = None
