"""INTERNAL: Consolidated generated types.

DO NOT import from this module directly.
Use 'from adcp import Type' or 'from adcp.types import Type' instead.

This module consolidates all generated types from generated_poc/ into a single
namespace for convenience. The leading underscore signals this is private API.

Auto-generated by datamodel-code-generator from JSON schemas.
DO NOT EDIT MANUALLY.

Generated from: https://github.com/adcontextprotocol/adcp/tree/main/schemas
Generation date: 2026-02-28 18:37:35 UTC
"""

# ruff: noqa: E501, I001
from __future__ import annotations

# Import all types from generated_poc modules
from adcp.types.generated_poc.enums.action_source import ActionSource
from adcp.types.generated_poc.enums.adcp_domain import AdcpDomain
from adcp.types.generated_poc.enums.age_verification_method import AgeVerificationMethod
from adcp.types.generated_poc.enums.asset_content_type import AssetContentType
from adcp.types.generated_poc.enums.attribution_model import AttributionModel
from adcp.types.generated_poc.enums.audience_source import AudienceSource
from adcp.types.generated_poc.enums.auth_scheme import AuthenticationScheme
from adcp.types.generated_poc.enums.available_metric import AvailableMetric
from adcp.types.generated_poc.enums.catalog_action import CatalogAction
from adcp.types.generated_poc.enums.catalog_item_status import CatalogItemStatus
from adcp.types.generated_poc.enums.catalog_type import CatalogType
from adcp.types.generated_poc.enums.channels import MediaChannel
from adcp.types.generated_poc.enums.co_branding_requirement import CoBrandingRequirement
from adcp.types.generated_poc.enums.consent_basis import ConsentBasis
from adcp.types.generated_poc.enums.content_id_type import ContentIdType
from adcp.types.generated_poc.enums.creative_action import CreativeAction
from adcp.types.generated_poc.enums.creative_agent_capability import CreativeAgentCapability
from adcp.types.generated_poc.enums.creative_approval_status import CreativeApprovalStatus
from adcp.types.generated_poc.enums.creative_sort_field import CreativeSortField
from adcp.types.generated_poc.enums.creative_status import CreativeStatus
from adcp.types.generated_poc.enums.daast_tracking_event import DaastTrackingEvent
from adcp.types.generated_poc.enums.daast_version import DaastVersion
from adcp.types.generated_poc.enums.day_of_week import DayOfWeek
from adcp.types.generated_poc.enums.delivery_type import DeliveryType
from adcp.types.generated_poc.enums.demographic_system import DemographicSystem
from adcp.types.generated_poc.enums.device_platform import DevicePlatform
from adcp.types.generated_poc.enums.device_type import DeviceType
from adcp.types.generated_poc.enums.digital_source_type import DigitalSourceType
from adcp.types.generated_poc.enums.dimension_unit import DimensionUnit
from adcp.types.generated_poc.enums.disclosure_position import DisclosurePosition
from adcp.types.generated_poc.enums.distance_unit import DistanceUnit
from adcp.types.generated_poc.enums.error_code import ErrorCode
from adcp.types.generated_poc.enums.event_type import EventType
from adcp.types.generated_poc.enums.feed_format import FeedFormat
from adcp.types.generated_poc.enums.feedback_source import FeedbackSource
from adcp.types.generated_poc.enums.forecast_method import ForecastMethod
from adcp.types.generated_poc.enums.forecast_range_unit import ForecastRangeUnit
from adcp.types.generated_poc.enums.forecastable_metric import ForecastableMetric
from adcp.types.generated_poc.enums.format_category import FormatCategory
from adcp.types.generated_poc.enums.format_id_parameter import FormatIdParameter
from adcp.types.generated_poc.enums.frequency_cap_scope import FrequencyCapScope
from adcp.types.generated_poc.enums.geo_level import GeographicTargetingLevel
from adcp.types.generated_poc.enums.history_entry_type import HistoryEntryType
from adcp.types.generated_poc.enums.http_method import HttpMethod
from adcp.types.generated_poc.enums.identifier_types import PropertyIdentifierTypes
from adcp.types.generated_poc.enums.javascript_module_type import JavascriptModuleType
from adcp.types.generated_poc.enums.landing_page_requirement import LandingPageRequirement
from adcp.types.generated_poc.enums.markdown_flavor import MarkdownFlavor
from adcp.types.generated_poc.enums.media_buy_status import MediaBuyStatus
from adcp.types.generated_poc.enums.metric_type import MetricType
from adcp.types.generated_poc.enums.metro_system import MetroAreaSystem
from adcp.types.generated_poc.enums.notification_type import NotificationType
from adcp.types.generated_poc.enums.pacing import Pacing
from adcp.types.generated_poc.enums.postal_system import PostalCodeSystem
from adcp.types.generated_poc.enums.preview_output_format import PreviewOutputFormat
from adcp.types.generated_poc.enums.pricing_model import PricingModel
from adcp.types.generated_poc.enums.property_type import PropertyType
from adcp.types.generated_poc.enums.publisher_identifier_types import PublisherIdentifierTypes
from adcp.types.generated_poc.enums.reach_unit import ReachUnit
from adcp.types.generated_poc.enums.reporting_frequency import ReportingFrequency
from adcp.types.generated_poc.enums.signal_catalog_type import SignalCatalogType
from adcp.types.generated_poc.enums.signal_source import SignalSource
from adcp.types.generated_poc.enums.signal_value_type import SignalValueType
from adcp.types.generated_poc.enums.sort_direction import SortDirection
from adcp.types.generated_poc.enums.sort_metric import SortMetric
from adcp.types.generated_poc.enums.task_status import TaskStatus
from adcp.types.generated_poc.enums.task_type import TaskType
from adcp.types.generated_poc.enums.transport_mode import TransportMode
from adcp.types.generated_poc.enums.uid_type import UidType
from adcp.types.generated_poc.enums.universal_macro import UniversalMacro
from adcp.types.generated_poc.enums.update_frequency import UpdateFrequency
from adcp.types.generated_poc.enums.url_asset_type import UrlAssetType
from adcp.types.generated_poc.enums.validation_mode import ValidationMode
from adcp.types.generated_poc.enums.vast_tracking_event import VastTrackingEvent
from adcp.types.generated_poc.enums.vast_version import VastVersion
from adcp.types.generated_poc.enums.wcag_level import WcagLevel
from adcp.types.generated_poc.enums.webhook_response_type import WebhookResponseType
from adcp.types.generated_poc.enums.webhook_security_method import WebhookSecurityMethod
from adcp.types.generated_poc.a2ui.component import A2UiComponent
from adcp.types.generated_poc.a2ui.surface import A2UiSurface
from adcp.types.generated_poc.account.get_account_financials_request import (
    GetAccountFinancialsRequest,
)
from adcp.types.generated_poc.account.get_account_financials_response import (
    Balance,
    Credit,
    GetAccountFinancialsResponse,
    GetAccountFinancialsResponse1,
    GetAccountFinancialsResponse2,
    Invoice,
    LastTopUp,
    PaymentStatus,
    Spend,
    Status,
)
from adcp.types.generated_poc.account.list_accounts_request import ListAccountsRequest
from adcp.types.generated_poc.account.list_accounts_response import ListAccountsResponse
from adcp.types.generated_poc.account.report_usage_request import ReportUsageRequest, UsageItem
from adcp.types.generated_poc.account.report_usage_response import ReportUsageResponse
from adcp.types.generated_poc.account.sync_accounts_request import (
    Account,
    Billing,
    SyncAccountsRequest,
)
from adcp.types.generated_poc.account.sync_accounts_response import (
    AccountScope,
    Action,
    CreditLimit,
    Setup,
    SyncAccountsResponse,
    SyncAccountsResponse1,
    SyncAccountsResponse2,
)
from adcp.types.generated_poc.adagents import (
    AdcpAgentsAuthorization,
    AdcpAgentsAuthorization1,
    AdcpAgentsAuthorization2,
    AuthorizedAgents,
    AuthorizedAgents1,
    AuthorizedAgents2,
    AuthorizedAgents3,
    AuthorizedAgents4,
    AuthorizedAgents5,
    Contact,
    PropertyFeature,
    SignalId,
    SignalTag,
    SignalTags,
    Tags,
)
from adcp.types.generated_poc.brand import (
    AgenticCheckout,
    Architecture,
    Asset,
    AuthorizedOperator,
    Avatar,
    Background,
    Brand,
    Brand1,
    BrandAgent,
    BrandDiscovery,
    BrandDiscovery1,
    BrandDiscovery2,
    BrandDiscovery3,
    BrandDiscovery4,
    BrandId,
    ColorValue,
    ColorValue1,
    ColorValue2,
    ColorValue2Item,
    Colors,
    Contact1,
    Country,
    Disclaimer,
    Domain,
    Fonts,
    House,
    KellerType,
    LocalizedName,
    Logo,
    Orientation,
    ProductCatalog,
    Property,
    Store,
    Tone,
    Trademark,
    Type,
    Variant,
    Voice,
)
from adcp.types.generated_poc.content_standards.artifact import (
    Artifact,
    AssetAccess,
    AssetAccess1,
    AssetAccess2,
    AssetAccess3,
    Assets,
    Assets1,
    Assets2,
    Assets3,
    Identifiers,
    Metadata,
    Provider,
    Role,
    TranscriptSource,
    TranscriptSource1,
)
from adcp.types.generated_poc.content_standards.artifact_webhook_payload import (
    ArtifactWebhookPayload,
    Pagination,
)
from adcp.types.generated_poc.content_standards.calibrate_content_request import (
    CalibrateContentRequest,
)
from adcp.types.generated_poc.content_standards.calibrate_content_response import (
    CalibrateContentResponse,
    CalibrateContentResponse1,
    CalibrateContentResponse2,
    Feature,
    Verdict,
)
from adcp.types.generated_poc.content_standards.content_standards import (
    CalibrationExemplars,
    ContentStandards,
)
from adcp.types.generated_poc.content_standards.create_content_standards_request import (
    CreateContentStandardsRequest,
    Fail,
    Pass,
    Scope,
)
from adcp.types.generated_poc.content_standards.create_content_standards_response import (
    CreateContentStandardsResponse,
    CreateContentStandardsResponse1,
    CreateContentStandardsResponse2,
)
from adcp.types.generated_poc.content_standards.get_content_standards_request import (
    GetContentStandardsRequest,
)
from adcp.types.generated_poc.content_standards.get_content_standards_response import (
    GetContentStandardsResponse,
    GetContentStandardsResponse1,
    GetContentStandardsResponse2,
)
from adcp.types.generated_poc.content_standards.get_media_buy_artifacts_request import (
    GetMediaBuyArtifactsRequest,
    Method,
    Sampling,
    TimeRange,
)
from adcp.types.generated_poc.content_standards.get_media_buy_artifacts_response import (
    BrandContext,
    GetMediaBuyArtifactsResponse,
    GetMediaBuyArtifactsResponse1,
    GetMediaBuyArtifactsResponse2,
    LocalVerdict,
    SamplingInfo,
)
from adcp.types.generated_poc.content_standards.list_content_standards_request import (
    ListContentStandardsRequest,
)
from adcp.types.generated_poc.content_standards.list_content_standards_response import (
    ListContentStandardsResponse,
    ListContentStandardsResponse1,
    ListContentStandardsResponse2,
)
from adcp.types.generated_poc.content_standards.update_content_standards_request import (
    UpdateContentStandardsRequest,
)
from adcp.types.generated_poc.content_standards.update_content_standards_response import (
    UpdateContentStandardsResponse,
    UpdateContentStandardsResponse1,
    UpdateContentStandardsResponse2,
)
from adcp.types.generated_poc.content_standards.validate_content_delivery_request import (
    Record,
    ValidateContentDeliveryRequest,
)
from adcp.types.generated_poc.content_standards.validate_content_delivery_response import (
    Result,
    Summary,
    ValidateContentDeliveryResponse,
    ValidateContentDeliveryResponse1,
    ValidateContentDeliveryResponse2,
)
from adcp.types.generated_poc.core.account_ref import (
    AccountReference,
    AccountReference1,
    AccountReference2,
)
from adcp.types.generated_poc.core.activation_key import (
    ActivationKey,
    ActivationKey1,
    ActivationKey2,
)
from adcp.types.generated_poc.core.assets.audio_asset import AudioAsset, BitDepth, Channels
from adcp.types.generated_poc.core.assets.brief_asset import BriefAsset
from adcp.types.generated_poc.core.assets.catalog_asset import CatalogAsset
from adcp.types.generated_poc.core.assets.css_asset import CssAsset
from adcp.types.generated_poc.core.assets.daast_asset import DaastAsset, DaastAsset1, DaastAsset2
from adcp.types.generated_poc.core.assets.html_asset import Accessibility, HtmlAsset
from adcp.types.generated_poc.core.assets.image_asset import ImageAsset
from adcp.types.generated_poc.core.assets.javascript_asset import JavascriptAsset
from adcp.types.generated_poc.core.assets.markdown_asset import MarkdownAsset
from adcp.types.generated_poc.core.assets.text_asset import TextAsset
from adcp.types.generated_poc.core.assets.url_asset import UrlAsset
from adcp.types.generated_poc.core.assets.vast_asset import VastAsset, VastAsset1, VastAsset2
from adcp.types.generated_poc.core.assets.video_asset import (
    AudioBitDepth,
    AudioChannels,
    ChromaSubsampling,
    ColorSpace,
    FrameRateType,
    GopType,
    HdrFormat,
    MoovAtomPosition,
    ScanType,
    VideoAsset,
    VideoBitDepth,
)
from adcp.types.generated_poc.core.assets.webhook_asset import Security, WebhookAsset
from adcp.types.generated_poc.core.async_response_data import AdcpAsyncResponseData
from adcp.types.generated_poc.core.attribution_window import AttributionWindow
from adcp.types.generated_poc.core.audience_member import (
    AudienceMember,
    AudienceMember1,
    AudienceMember2,
    AudienceMember3,
    Uid,
)
from adcp.types.generated_poc.core.brand_ref import BrandReference
from adcp.types.generated_poc.core.catalog import Catalog, Gtin
from adcp.types.generated_poc.core.catalog_field_mapping import CatalogFieldMapping, Transform
from adcp.types.generated_poc.core.catchment import (
    Catchment,
    Catchment1,
    Catchment2,
    Catchment3,
    Geometry,
    Geometry1,
    Geometry2,
    Radius,
    TravelTime,
    TravelTime1,
    TravelTime2,
    Unit,
)
from adcp.types.generated_poc.core.context import ContextObject
from adcp.types.generated_poc.core.creative_asset import CreativeAsset, Input
from adcp.types.generated_poc.core.creative_assignment import CreativeAssignment
from adcp.types.generated_poc.core.creative_brief import (
    Compliance,
    CreativeBrief,
    Jurisdiction,
    Messaging,
    Objective,
    RequiredDisclosure,
)
from adcp.types.generated_poc.core.creative_filters import CreativeFilters
from adcp.types.generated_poc.core.creative_manifest import CreativeManifest
from adcp.types.generated_poc.core.creative_policy import CreativePolicy
from adcp.types.generated_poc.core.creative_variant import CreativeVariant, GenerationContext
from adcp.types.generated_poc.core.data_provider_signal_selector import (
    DataProviderSignalSelector,
    DataProviderSignalSelector1,
    DataProviderSignalSelector2,
    DataProviderSignalSelector3,
)
from adcp.types.generated_poc.core.date_range import DateRange
from adcp.types.generated_poc.core.datetime_range import DatetimeRange
from adcp.types.generated_poc.core.daypart_target import DaypartTarget
from adcp.types.generated_poc.core.delivery_forecast import DeliveryForecast
from adcp.types.generated_poc.core.delivery_metrics import (
    ByActionSourceItem,
    ByEventTypeItem,
    DeliveryMetrics,
    DoohMetrics,
    QuartileData,
    Standard,
    VenueBreakdownItem,
    Viewability,
)
from adcp.types.generated_poc.core.deployment import Deployment, Deployment1, Deployment2
from adcp.types.generated_poc.core.destination import Destination, Destination1, Destination2
from adcp.types.generated_poc.core.destination_item import (
    DestinationItem,
    DestinationType,
    Location,
)
from adcp.types.generated_poc.core.duration import Duration
from adcp.types.generated_poc.core.education_item import DegreeType, EducationItem, Level, Modality
from adcp.types.generated_poc.core.error import Error, Recovery
from adcp.types.generated_poc.core.event import Event
from adcp.types.generated_poc.core.event_custom_data import Content, EventCustomData
from adcp.types.generated_poc.core.ext import ExtensionObject
from adcp.types.generated_poc.core.flight_item import FlightItem, Origin
from adcp.types.generated_poc.core.forecast_point import ForecastPoint, Metrics
from adcp.types.generated_poc.core.forecast_range import ForecastRange
from adcp.types.generated_poc.core.format import (
    Assets10,
    Assets11,
    Assets12,
    Assets13,
    Assets14,
    Assets15,
    Assets16,
    Assets17,
    Assets18,
    Assets19,
    Assets20,
    Assets21,
    Assets22,
    Assets23,
    Assets24,
    Assets25,
    Assets26,
    Assets27,
    Assets28,
    Assets29,
    Assets30,
    Assets5,
    Assets6,
    Assets7,
    Assets8,
    Assets9,
    BaseGroupAsset,
    BaseIndividualAsset,
    Dimensions,
    Dimensions1,
    Format,
    FormatCard,
    FormatCardDetailed,
    Renders,
    Renders1,
    Responsive,
    SelectionMode,
)
from adcp.types.generated_poc.core.format_id import FormatId
from adcp.types.generated_poc.core.frequency_cap import (
    FrequencyCap,
    FrequencyCap1,
    FrequencyCap2,
    FrequencyCap3,
)
from adcp.types.generated_poc.core.geo_breakdown_support import GeographicBreakdownSupport
from adcp.types.generated_poc.core.hotel_item import Address, HotelItem
from adcp.types.generated_poc.core.identifier import Identifier
from adcp.types.generated_poc.core.job_item import (
    EmploymentType,
    ExperienceLevel,
    JobItem,
    Period,
    Salary,
)
from adcp.types.generated_poc.core.mcp_webhook_payload import McpWebhookPayload
from adcp.types.generated_poc.core.media_buy import MediaBuy
from adcp.types.generated_poc.core.media_buy_features import MediaBuyFeatures
from adcp.types.generated_poc.core.offering import GeoTargets, Metro, Offering, PostalArea, Region
from adcp.types.generated_poc.core.offering_asset_group import OfferingAssetGroup
from adcp.types.generated_poc.core.optimization_goal import (
    EventSource,
    Metric,
    OptimizationGoal,
    OptimizationGoal1,
    OptimizationGoal2,
    Target,
    Target1,
    Target2,
    Target3,
    Target4,
    TargetFrequency,
    TargetFrequency1,
)
from adcp.types.generated_poc.core.outcome_measurement import OutcomeMeasurement
from adcp.types.generated_poc.core.overlay import Bounds, Overlay, Visual
from adcp.types.generated_poc.core.pagination_request import PaginationRequest
from adcp.types.generated_poc.core.pagination_response import PaginationResponse
from adcp.types.generated_poc.core.performance_feedback import (
    MeasurementPeriod,
    PerformanceFeedback,
)
from adcp.types.generated_poc.core.placement import Placement
from adcp.types.generated_poc.core.price import Price
from adcp.types.generated_poc.core.pricing_option import PricingOption
from adcp.types.generated_poc.core.product import (
    CatalogMatch,
    ConversionTracking,
    DeliveryMeasurement,
    MatchedGtin,
    MetricOptimization,
    Product,
    ProductCard,
    ProductCardDetailed,
    SupportedMetric,
    SupportedTarget,
    SupportedTarget1,
    SupportedViewDuration,
)
from adcp.types.generated_poc.core.product_allocation import ProductAllocation
from adcp.types.generated_poc.core.product_filters import (
    BudgetRange,
    BudgetRange1,
    ProductFilters,
    RequiredGeoTargetingItem,
)
from adcp.types.generated_poc.core.property_id import PropertyId
from adcp.types.generated_poc.core.property_list_ref import PropertyListReference
from adcp.types.generated_poc.core.property_tag import PropertyTag
from adcp.types.generated_poc.core.proposal import Proposal, TotalBudgetGuidance
from adcp.types.generated_poc.core.protocol_envelope import ProtocolEnvelope
from adcp.types.generated_poc.core.provenance import (
    AiTool,
    C2pa,
    DeclaredBy,
    Disclosure,
    HumanOversight,
    Provenance,
    VerificationItem,
)
from adcp.types.generated_poc.core.publisher_property_selector import (
    PublisherPropertySelector,
    PublisherPropertySelector1,
    PublisherPropertySelector2,
    PublisherPropertySelector3,
)
from adcp.types.generated_poc.core.push_notification_config import (
    Authentication,
    PushNotificationConfig,
)
from adcp.types.generated_poc.core.real_estate_item import Area, ListingType, RealEstateItem
from adcp.types.generated_poc.core.reference_asset import ReferenceAsset
from adcp.types.generated_poc.core.reporting_capabilities import (
    DateRangeSupport,
    ReportingCapabilities,
)
from adcp.types.generated_poc.core.reporting_webhook import ReportingWebhook
from adcp.types.generated_poc.core.requirements.asset_requirements import AssetRequirements
from adcp.types.generated_poc.core.requirements.audio_asset_requirements import (
    AudioAssetRequirements,
    Channel,
    SampleRate,
)
from adcp.types.generated_poc.core.requirements.catalog_field_binding import (
    AssetPoolBinding,
    CatalogFieldBinding,
    CatalogFieldBinding1,
    ScalarBinding,
)
from adcp.types.generated_poc.core.requirements.catalog_requirements import CatalogRequirements
from adcp.types.generated_poc.core.requirements.css_asset_requirements import CssAssetRequirements
from adcp.types.generated_poc.core.requirements.daast_asset_requirements import (
    DaastAssetRequirements,
)
from adcp.types.generated_poc.core.requirements.html_asset_requirements import (
    HtmlAssetRequirements,
    Sandbox,
)
from adcp.types.generated_poc.core.requirements.image_asset_requirements import (
    ImageAssetRequirements,
)
from adcp.types.generated_poc.core.requirements.javascript_asset_requirements import (
    JavascriptAssetRequirements,
    ModuleType,
)
from adcp.types.generated_poc.core.requirements.markdown_asset_requirements import (
    MarkdownAssetRequirements,
)
from adcp.types.generated_poc.core.requirements.offering_asset_constraint import (
    OfferingAssetConstraint,
)
from adcp.types.generated_poc.core.requirements.text_asset_requirements import TextAssetRequirements
from adcp.types.generated_poc.core.requirements.url_asset_requirements import (
    Protocol,
    UrlAssetRequirements,
)
from adcp.types.generated_poc.core.requirements.vast_asset_requirements import VastAssetRequirements
from adcp.types.generated_poc.core.requirements.video_asset_requirements import (
    Codec,
    Container,
    FrameRate,
    VideoAssetRequirements,
)
from adcp.types.generated_poc.core.requirements.webhook_asset_requirements import (
    WebhookAssetRequirements,
)
from adcp.types.generated_poc.core.response import ProtocolResponse
from adcp.types.generated_poc.core.signal_definition import Range, SignalDefinition, Tag
from adcp.types.generated_poc.core.signal_filters import SignalFilters
from adcp.types.generated_poc.core.signal_id import SignalId2, SignalId3
from adcp.types.generated_poc.core.signal_pricing import (
    SignalPricing,
    SignalPricing1,
    SignalPricing2,
    SignalPricing3,
)
from adcp.types.generated_poc.core.signal_pricing_option import (
    SignalPricingOption,
    SignalPricingOption1,
    SignalPricingOption2,
    SignalPricingOption3,
    SignalPricingOption4,
    SignalPricingOption5,
    SignalPricingOption6,
    SignalPricingOption7,
)
from adcp.types.generated_poc.core.signal_targeting import (
    SignalTargeting,
    SignalTargeting1,
    SignalTargeting2,
    SignalTargeting3,
)
from adcp.types.generated_poc.core.start_timing import StartTiming
from adcp.types.generated_poc.core.store_item import StoreItem
from adcp.types.generated_poc.core.sub_asset import SubAsset, SubAsset1, SubAsset2
from adcp.types.generated_poc.core.targeting import (
    AgeRestriction,
    GeoCountriesExcludeItem,
    GeoCountry,
    GeoMetro,
    GeoMetrosExcludeItem,
    GeoPostalArea,
    GeoPostalAreasExcludeItem,
    GeoProximity,
    GeoProximity2,
    GeoProximity3,
    GeoRegion,
    GeoRegionsExcludeItem,
    Geometry4,
    Geometry5,
    KeywordTarget,
    LanguageItem,
    MatchType,
    NegativeKeyword,
    StoreCatchment,
    TargetingOverlay,
    TravelTime4,
    TravelTime5,
)
from adcp.types.generated_poc.core.user_match import (
    UserMatch,
    UserMatch1,
    UserMatch2,
    UserMatch3,
    UserMatch4,
    UserMatch5,
)
from adcp.types.generated_poc.core.vehicle_item import (
    BodyStyle,
    Condition,
    FuelType,
    Mileage,
    Transmission,
    VehicleItem,
)
from adcp.types.generated_poc.creative.creative_feature_result import CreativeFeatureResult
from adcp.types.generated_poc.creative.get_creative_delivery_request import (
    GetCreativeDeliveryRequest,
    GetCreativeDeliveryRequest1,
    GetCreativeDeliveryRequest2,
    GetCreativeDeliveryRequest3,
)
from adcp.types.generated_poc.creative.get_creative_delivery_response import (
    Creative,
    GetCreativeDeliveryResponse,
    ReportingPeriod,
)
from adcp.types.generated_poc.creative.get_creative_features_request import (
    GetCreativeFeaturesRequest,
)
from adcp.types.generated_poc.creative.get_creative_features_response import (
    GetCreativeFeaturesResponse,
    GetCreativeFeaturesResponse1,
    GetCreativeFeaturesResponse2,
)
from adcp.types.generated_poc.creative.list_creative_formats_request import (
    AssetType,
    ListCreativeFormatsRequestCreativeAgent,
)
from adcp.types.generated_poc.creative.list_creative_formats_response import (
    CreativeAgent,
    ListCreativeFormatsResponseCreativeAgent,
)
from adcp.types.generated_poc.creative.preview_creative_request import (
    Input2,
    PreviewCreativeRequest,
    PreviewCreativeRequest1,
    PreviewCreativeRequest2,
    PreviewCreativeRequest3,
    Request,
)
from adcp.types.generated_poc.creative.preview_creative_response import (
    Input4,
    Preview,
    Preview1,
    Preview2,
    Preview3,
    PreviewCreativeResponse,
    PreviewCreativeResponse1,
    PreviewCreativeResponse2,
    PreviewCreativeResponse3,
    Response,
    Response1,
    Results,
    Results1,
)
from adcp.types.generated_poc.creative.preview_render import (
    Embedding,
    PreviewRender,
    PreviewRender1,
    PreviewRender2,
    PreviewRender3,
)
from adcp.types.generated_poc.extensions.extension_meta import AdcpExtensionFileSchema
from adcp.types.generated_poc.media_buy.build_creative_request import BuildCreativeRequest
from adcp.types.generated_poc.media_buy.build_creative_response import (
    BuildCreativeResponse,
    BuildCreativeResponse1,
    BuildCreativeResponse2,
)
from adcp.types.generated_poc.media_buy.create_media_buy_async_response_input_required import (
    CreateMediaBuyInputRequired,
    Reason,
)
from adcp.types.generated_poc.media_buy.create_media_buy_async_response_submitted import (
    CreateMediaBuySubmitted,
)
from adcp.types.generated_poc.media_buy.create_media_buy_async_response_working import (
    CreateMediaBuyWorking,
)
from adcp.types.generated_poc.media_buy.create_media_buy_request import (
    ArtifactWebhook,
    BatchFrequency,
    CreateMediaBuyRequest,
    DeliveryMode,
    TotalBudget,
)
from adcp.types.generated_poc.media_buy.create_media_buy_response import (
    CreateMediaBuyResponse,
    CreateMediaBuyResponse1,
    CreateMediaBuyResponse2,
)
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_request import (
    Geo,
    GetMediaBuyDeliveryRequest,
    ReportingDimensions,
    StatusFilter,
)
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_response import (
    AggregatedTotals,
    ByAudienceItem,
    ByCatalogItemItem,
    ByCreativeItem,
    ByDevicePlatformItem,
    ByDeviceTypeItem,
    ByGeoItem,
    ByKeywordItem,
    ByPackageItem,
    ByPlacementItem,
    DailyBreakdownItem,
    DailyBreakdownItem1,
    GetMediaBuyDeliveryResponse,
    MediaBuyDelivery,
    Totals,
)
from adcp.types.generated_poc.media_buy.get_media_buys_request import GetMediaBuysRequest
from adcp.types.generated_poc.media_buy.get_media_buys_response import (
    CreativeApproval,
    GetMediaBuysResponse,
    Snapshot,
    SnapshotUnavailableReason,
)
from adcp.types.generated_poc.media_buy.get_products_async_response_input_required import (
    GetProductsInputRequired,
)
from adcp.types.generated_poc.media_buy.get_products_async_response_submitted import (
    GetProductsSubmitted,
)
from adcp.types.generated_poc.media_buy.get_products_async_response_working import (
    GetProductsWorking,
)
from adcp.types.generated_poc.media_buy.get_products_request import (
    Action2,
    BuyingMode,
    FieldModel,
    GetProductsRequest,
    GetProductsRequest1,
    GetProductsRequest2,
    GetProductsRequest3,
    Refine,
    Refine1,
    Refine2,
)
from adcp.types.generated_poc.media_buy.get_products_response import (
    GetProductsResponse,
    RefinementAppliedItem,
)
from adcp.types.generated_poc.media_buy.list_creative_formats_request import (
    ListCreativeFormatsRequest,
)
from adcp.types.generated_poc.media_buy.list_creative_formats_response import (
    ListCreativeFormatsResponse,
)
from adcp.types.generated_poc.media_buy.list_creatives_request import (
    Field1,
    ListCreativesRequest,
    Sort,
)
from adcp.types.generated_poc.media_buy.list_creatives_response import (
    AssignedPackage,
    Assignments,
    ListCreativesResponse,
    Performance,
    QuerySummary,
    SortApplied,
    StatusSummary,
)
from adcp.types.generated_poc.media_buy.log_event_request import LogEventRequest
from adcp.types.generated_poc.media_buy.log_event_response import (
    LogEventResponse,
    LogEventResponse1,
    LogEventResponse2,
    PartialFailure,
)
from adcp.types.generated_poc.media_buy.package_request import PackageRequest
from adcp.types.generated_poc.media_buy.package_update import (
    KeywordTargetsAddItem,
    KeywordTargetsAddItem1,
    KeywordTargetsRemoveItem,
    KeywordTargetsRemoveItem1,
    NegativeKeywordsAddItem,
    NegativeKeywordsAddItem1,
    NegativeKeywordsRemoveItem,
    NegativeKeywordsRemoveItem1,
    PackageUpdate,
    PackageUpdate1,
    PackageUpdate2,
)
from adcp.types.generated_poc.media_buy.provide_performance_feedback_request import (
    ProvidePerformanceFeedbackRequest,
    ProvidePerformanceFeedbackRequest1,
    ProvidePerformanceFeedbackRequest2,
)
from adcp.types.generated_poc.media_buy.provide_performance_feedback_response import (
    ProvidePerformanceFeedbackResponse,
    ProvidePerformanceFeedbackResponse1,
    ProvidePerformanceFeedbackResponse2,
)
from adcp.types.generated_poc.media_buy.sync_audiences_request import (
    AudienceType,
    SyncAudiencesRequest,
)
from adcp.types.generated_poc.media_buy.sync_audiences_response import (
    SyncAudiencesResponse,
    SyncAudiencesResponse1,
    SyncAudiencesResponse2,
)
from adcp.types.generated_poc.media_buy.sync_catalogs_async_response_input_required import (
    SyncCatalogsInputRequired,
)
from adcp.types.generated_poc.media_buy.sync_catalogs_async_response_submitted import (
    SyncCatalogsSubmitted,
)
from adcp.types.generated_poc.media_buy.sync_catalogs_async_response_working import (
    SyncCatalogsWorking,
)
from adcp.types.generated_poc.media_buy.sync_catalogs_request import SyncCatalogsRequest
from adcp.types.generated_poc.media_buy.sync_catalogs_response import (
    ItemIssue,
    SyncCatalogsResponse,
    SyncCatalogsResponse1,
    SyncCatalogsResponse2,
)
from adcp.types.generated_poc.media_buy.sync_creatives_async_response_input_required import (
    SyncCreativesInputRequired,
)
from adcp.types.generated_poc.media_buy.sync_creatives_async_response_submitted import (
    SyncCreativesSubmitted,
)
from adcp.types.generated_poc.media_buy.sync_creatives_async_response_working import (
    SyncCreativesWorking,
)
from adcp.types.generated_poc.media_buy.sync_creatives_request import (
    Assignment,
    SyncCreativesRequest,
)
from adcp.types.generated_poc.media_buy.sync_creatives_response import (
    SyncCreativesResponse,
    SyncCreativesResponse1,
    SyncCreativesResponse2,
)
from adcp.types.generated_poc.media_buy.sync_event_sources_request import SyncEventSourcesRequest
from adcp.types.generated_poc.media_buy.sync_event_sources_response import (
    ManagedBy,
    SnippetType,
    SyncEventSourcesResponse,
    SyncEventSourcesResponse1,
    SyncEventSourcesResponse2,
)
from adcp.types.generated_poc.media_buy.update_media_buy_async_response_input_required import (
    UpdateMediaBuyInputRequired,
)
from adcp.types.generated_poc.media_buy.update_media_buy_async_response_submitted import (
    UpdateMediaBuySubmitted,
)
from adcp.types.generated_poc.media_buy.update_media_buy_async_response_working import (
    UpdateMediaBuyWorking,
)
from adcp.types.generated_poc.media_buy.update_media_buy_request import (
    UpdateMediaBuyRequest,
    UpdateMediaBuyRequest1,
    UpdateMediaBuyRequest2,
)
from adcp.types.generated_poc.media_buy.update_media_buy_response import (
    UpdateMediaBuyResponse,
    UpdateMediaBuyResponse1,
    UpdateMediaBuyResponse2,
)
from adcp.types.generated_poc.pricing_options.cpa_option import CpaPricingOption
from adcp.types.generated_poc.pricing_options.cpc_option import CpcPricingOption
from adcp.types.generated_poc.pricing_options.cpcv_option import CpcvPricingOption
from adcp.types.generated_poc.pricing_options.cpm_option import CpmPricingOption
from adcp.types.generated_poc.pricing_options.cpp_option import CppPricingOption, Parameters
from adcp.types.generated_poc.pricing_options.cpv_option import (
    CpvPricingOption,
    ViewThreshold,
    ViewThreshold1,
)
from adcp.types.generated_poc.pricing_options.flat_rate_option import FlatRatePricingOption
from adcp.types.generated_poc.pricing_options.price_guidance import PriceGuidance
from adcp.types.generated_poc.pricing_options.time_option import TimeBasedPricingOption, TimeUnit
from adcp.types.generated_poc.pricing_options.vcpm_option import VcpmPricingOption
from adcp.types.generated_poc.property.base_property_source import (
    BasePropertySource,
    BasePropertySource1,
    BasePropertySource2,
    BasePropertySource3,
)
from adcp.types.generated_poc.property.create_property_list_request import CreatePropertyListRequest
from adcp.types.generated_poc.property.create_property_list_response import (
    CreatePropertyListResponse,
)
from adcp.types.generated_poc.property.delete_property_list_request import DeletePropertyListRequest
from adcp.types.generated_poc.property.delete_property_list_response import (
    DeletePropertyListResponse,
)
from adcp.types.generated_poc.property.feature_requirement import FeatureRequirement, IfNotCovered
from adcp.types.generated_poc.property.get_property_list_request import GetPropertyListRequest
from adcp.types.generated_poc.property.get_property_list_response import GetPropertyListResponse
from adcp.types.generated_poc.property.list_property_lists_request import ListPropertyListsRequest
from adcp.types.generated_poc.property.list_property_lists_response import ListPropertyListsResponse
from adcp.types.generated_poc.property.property_error import Code, PropertyError
from adcp.types.generated_poc.property.property_feature_definition import (
    Coverage,
    PropertyFeatureDefinition,
)
from adcp.types.generated_poc.property.property_list import PropertyList
from adcp.types.generated_poc.property.property_list_changed_webhook import (
    ChangeSummary,
    PropertyListChangedWebhook,
)
from adcp.types.generated_poc.property.property_list_filters import (
    CountriesAllItem,
    PropertyListFilters,
)
from adcp.types.generated_poc.property.update_property_list_request import UpdatePropertyListRequest
from adcp.types.generated_poc.property.update_property_list_response import (
    UpdatePropertyListResponse,
)
from adcp.types.generated_poc.protocol.get_adcp_capabilities_request import (
    GetAdcpCapabilitiesRequest,
)
from adcp.types.generated_poc.protocol.get_adcp_capabilities_response import (
    AccountResolution,
    Adcp,
    AudienceTargeting,
    AvailableDimension,
    CreativeFeature,
    CreativeSpecs,
    DataProviderDomain,
    Endpoint,
    Execution,
    ExtensionsSupportedItem,
    Features,
    GeoMetros,
    GeoPostalAreas,
    GetAdcpCapabilitiesResponse,
    Governance,
    KeywordTargets,
    MajorVersion,
    MatchingLatencyHours,
    MraidVersion,
    NegativeKeywords,
    Portfolio,
    Preferred,
    PrimaryCountry,
    PublisherDomain,
    Reporting,
    Signals,
    SponsoredIntelligence,
    SupportedBillingEnum,
    SupportedIdentifierType,
    SupportedMatchType,
    SupportedProtocol,
    Targeting,
    Transport,
)
from adcp.types.generated_poc.signals.activate_signal_request import ActivateSignalRequest
from adcp.types.generated_poc.signals.activate_signal_response import (
    ActivateSignalResponse,
    ActivateSignalResponse1,
    ActivateSignalResponse2,
)
from adcp.types.generated_poc.signals.get_signals_request import (
    GetSignalsRequest,
    GetSignalsRequest1,
    GetSignalsRequest2,
)
from adcp.types.generated_poc.signals.get_signals_response import GetSignalsResponse, Signal
from adcp.types.generated_poc.sponsored_intelligence.si_capabilities import (
    A2ui,
    Commerce,
    Components,
    Modalities,
    SiCapabilities,
    StandardEnum,
    Video,
)
from adcp.types.generated_poc.sponsored_intelligence.si_get_offering_request import (
    SiGetOfferingRequest,
)
from adcp.types.generated_poc.sponsored_intelligence.si_get_offering_response import (
    MatchingProduct,
    SiGetOfferingResponse,
)
from adcp.types.generated_poc.sponsored_intelligence.si_identity import (
    ConsentScopeEnum,
    PrivacyPolicyAcknowledged,
    ShippingAddress,
    SiIdentity,
    User,
)
from adcp.types.generated_poc.sponsored_intelligence.si_initiate_session_request import (
    SiInitiateSessionRequest,
)
from adcp.types.generated_poc.sponsored_intelligence.si_initiate_session_response import (
    SiInitiateSessionResponse,
)
from adcp.types.generated_poc.sponsored_intelligence.si_send_message_request import (
    ActionResponse,
    SiSendMessageRequest,
    SiSendMessageRequest1,
    SiSendMessageRequest2,
)
from adcp.types.generated_poc.sponsored_intelligence.si_send_message_response import (
    ContextForCheckout,
    Handoff,
    Intent,
    SessionStatus,
    SiSendMessageResponse,
)
from adcp.types.generated_poc.sponsored_intelligence.si_terminate_session_request import (
    SiTerminateSessionRequest,
    TerminationContext,
    TransactionIntent,
)
from adcp.types.generated_poc.sponsored_intelligence.si_terminate_session_response import (
    AcpHandoff,
    FollowUp,
    SiTerminateSessionResponse,
)
from adcp.types.generated_poc.sponsored_intelligence.si_ui_element import SiUiElement

# Special imports for name collisions (qualified names for types defined in multiple modules)
from adcp.types.generated_poc.core.package import Package as _PackageFromPackage
from adcp.types.generated_poc.media_buy.get_media_buys_response import (
    Package as _PackageFromGetMediaBuysResponse,
)
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_response import (
    DeliveryStatus as _DeliveryStatusFromGetMediaBuyDeliveryResponse,
)
from adcp.types.generated_poc.media_buy.get_media_buys_response import (
    DeliveryStatus as _DeliveryStatusFromGetMediaBuysResponse,
)
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_request import (
    Audience as _AudienceFromGetMediaBuyDeliveryRequest,
)
from adcp.types.generated_poc.media_buy.sync_audiences_request import (
    Audience as _AudienceFromSyncAudiencesRequest,
)
from adcp.types.generated_poc.media_buy.sync_audiences_response import (
    Audience as _AudienceFromSyncAudiencesResponse,
)

# Backward compatibility aliases for renamed types
MediaBuyPackage = _PackageFromGetMediaBuysResponse
DeliveryStatus = _DeliveryStatusFromGetMediaBuysResponse

# Backwards-compat: Types removed from upstream schemas.
from adcp.types.base import AdCPBaseModel as _AdCPBaseModel
from enum import Enum as _Enum
from pydantic import ConfigDict as _ConfigDict


class BrandManifest(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


# PromotedOfferings and related types are superseded by Catalog with type='offering'.
class PromotedOfferings(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


class PromotedOfferingsAssetRequirements(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


# Preserved as Enum (not model) so attribute access and iteration still work.
class PromotedOfferingsRequirement(str, _Enum):
    si_agent_url = "si_agent_url"
    offerings = "offerings"
    brand_logos = "brand.logos"
    brand_colors = "brand.colors"
    brand_tone = "brand.tone"
    brand_assets = "brand.assets"
    brand_product_catalog = "brand.product_catalog"


class PromotedProducts(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


class AssetSelectors(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


# DeliverTo was removed in upstream schemas (v2.5.x). The GetSignalsRequest wire
# format changed: 'deliver_to' nested object with 'deployments'+'countries' was
# replaced by top-level 'destinations' and 'countries' fields. Code using
# GetSignalsRequest(deliver_to=DeliverTo(...)) must migrate to the new field names.
# This stub prevents ImportError only; it cannot preserve the old wire behavior.
class DeliverTo(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


class DeliverTo1(DeliverTo):
    pass


# Pricing was removed in upstream schemas (v2.5.x). Replaced by SignalPricingOption
# which has the same cpm/currency fields. This stub preserves imports only.
class Pricing(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


# Measurement was renamed to OutcomeMeasurement upstream. This alias preserves imports.
Measurement = OutcomeMeasurement


# ListAuthorizedProperties was removed from upstream schemas.
# Replaced by adagents.json-based authorization model.
class ListAuthorizedPropertiesRequest(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


class ListAuthorizedPropertiesResponse(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


# PackageStatus enum was removed from upstream schemas.
class PackageStatus(str, _Enum):
    draft = "draft"
    active = "active"
    paused = "paused"
    completed = "completed"


# Explicit exports
__all__ = [
    "A2UiComponent",
    "A2UiSurface",
    "A2ui",
    "Accessibility",
    "Account",
    "AccountReference",
    "AccountReference1",
    "AccountReference2",
    "AccountResolution",
    "AccountScope",
    "AcpHandoff",
    "Action",
    "Action2",
    "ActionResponse",
    "ActionSource",
    "ActivateSignalRequest",
    "ActivateSignalResponse",
    "ActivateSignalResponse1",
    "ActivateSignalResponse2",
    "ActivationKey",
    "ActivationKey1",
    "ActivationKey2",
    "Adcp",
    "AdcpAgentsAuthorization",
    "AdcpAgentsAuthorization1",
    "AdcpAgentsAuthorization2",
    "AdcpAsyncResponseData",
    "AdcpDomain",
    "AdcpExtensionFileSchema",
    "Address",
    "AgeRestriction",
    "AgeVerificationMethod",
    "AgenticCheckout",
    "AggregatedTotals",
    "AiTool",
    "Architecture",
    "Area",
    "Artifact",
    "ArtifactWebhook",
    "ArtifactWebhookPayload",
    "Asset",
    "AssetAccess",
    "AssetAccess1",
    "AssetAccess2",
    "AssetAccess3",
    "AssetContentType",
    "AssetPoolBinding",
    "AssetRequirements",
    "AssetSelectors",
    "AssetType",
    "Assets",
    "Assets1",
    "Assets10",
    "Assets11",
    "Assets12",
    "Assets13",
    "Assets14",
    "Assets15",
    "Assets16",
    "Assets17",
    "Assets18",
    "Assets19",
    "Assets2",
    "Assets20",
    "Assets21",
    "Assets22",
    "Assets23",
    "Assets24",
    "Assets25",
    "Assets26",
    "Assets27",
    "Assets28",
    "Assets29",
    "Assets3",
    "Assets30",
    "Assets5",
    "Assets6",
    "Assets7",
    "Assets8",
    "Assets9",
    "AssignedPackage",
    "Assignment",
    "Assignments",
    "AttributionModel",
    "AttributionWindow",
    "AudienceMember",
    "AudienceMember1",
    "AudienceMember2",
    "AudienceMember3",
    "AudienceSource",
    "AudienceTargeting",
    "AudienceType",
    "AudioAsset",
    "AudioAssetRequirements",
    "AudioBitDepth",
    "AudioChannels",
    "Authentication",
    "AuthenticationScheme",
    "AuthorizedAgents",
    "AuthorizedAgents1",
    "AuthorizedAgents2",
    "AuthorizedAgents3",
    "AuthorizedAgents4",
    "AuthorizedAgents5",
    "AuthorizedOperator",
    "AvailableDimension",
    "AvailableMetric",
    "Avatar",
    "Background",
    "Balance",
    "BaseGroupAsset",
    "BaseIndividualAsset",
    "BasePropertySource",
    "BasePropertySource1",
    "BasePropertySource2",
    "BasePropertySource3",
    "BatchFrequency",
    "Billing",
    "BitDepth",
    "BodyStyle",
    "Bounds",
    "Brand",
    "Brand1",
    "BrandAgent",
    "BrandContext",
    "BrandDiscovery",
    "BrandDiscovery1",
    "BrandDiscovery2",
    "BrandDiscovery3",
    "BrandDiscovery4",
    "BrandId",
    "BrandManifest",
    "BrandReference",
    "BriefAsset",
    "BudgetRange",
    "BudgetRange1",
    "BuildCreativeRequest",
    "BuildCreativeResponse",
    "BuildCreativeResponse1",
    "BuildCreativeResponse2",
    "BuyingMode",
    "ByActionSourceItem",
    "ByAudienceItem",
    "ByCatalogItemItem",
    "ByCreativeItem",
    "ByDevicePlatformItem",
    "ByDeviceTypeItem",
    "ByEventTypeItem",
    "ByGeoItem",
    "ByKeywordItem",
    "ByPackageItem",
    "ByPlacementItem",
    "C2pa",
    "CalibrateContentRequest",
    "CalibrateContentResponse",
    "CalibrateContentResponse1",
    "CalibrateContentResponse2",
    "CalibrationExemplars",
    "Catalog",
    "CatalogAction",
    "CatalogAsset",
    "CatalogFieldBinding",
    "CatalogFieldBinding1",
    "CatalogFieldMapping",
    "CatalogItemStatus",
    "CatalogMatch",
    "CatalogRequirements",
    "CatalogType",
    "Catchment",
    "Catchment1",
    "Catchment2",
    "Catchment3",
    "ChangeSummary",
    "Channel",
    "Channels",
    "ChromaSubsampling",
    "CoBrandingRequirement",
    "Code",
    "Codec",
    "ColorSpace",
    "ColorValue",
    "ColorValue1",
    "ColorValue2",
    "ColorValue2Item",
    "Colors",
    "Commerce",
    "Compliance",
    "Components",
    "Condition",
    "ConsentBasis",
    "ConsentScopeEnum",
    "Contact",
    "Contact1",
    "Container",
    "Content",
    "ContentIdType",
    "ContentStandards",
    "ContextForCheckout",
    "ContextObject",
    "ConversionTracking",
    "CountriesAllItem",
    "Country",
    "Coverage",
    "CpaPricingOption",
    "CpcPricingOption",
    "CpcvPricingOption",
    "CpmPricingOption",
    "CppPricingOption",
    "CpvPricingOption",
    "CreateContentStandardsRequest",
    "CreateContentStandardsResponse",
    "CreateContentStandardsResponse1",
    "CreateContentStandardsResponse2",
    "CreateMediaBuyInputRequired",
    "CreateMediaBuyRequest",
    "CreateMediaBuyResponse",
    "CreateMediaBuyResponse1",
    "CreateMediaBuyResponse2",
    "CreateMediaBuySubmitted",
    "CreateMediaBuyWorking",
    "CreatePropertyListRequest",
    "CreatePropertyListResponse",
    "Creative",
    "CreativeAction",
    "CreativeAgent",
    "CreativeAgentCapability",
    "CreativeApproval",
    "CreativeApprovalStatus",
    "CreativeAsset",
    "CreativeAssignment",
    "CreativeBrief",
    "CreativeFeature",
    "CreativeFeatureResult",
    "CreativeFilters",
    "CreativeManifest",
    "CreativePolicy",
    "CreativeSortField",
    "CreativeSpecs",
    "CreativeStatus",
    "CreativeVariant",
    "Credit",
    "CreditLimit",
    "CssAsset",
    "CssAssetRequirements",
    "DaastAsset",
    "DaastAsset1",
    "DaastAsset2",
    "DaastAssetRequirements",
    "DaastTrackingEvent",
    "DaastVersion",
    "DailyBreakdownItem",
    "DailyBreakdownItem1",
    "DataProviderDomain",
    "DataProviderSignalSelector",
    "DataProviderSignalSelector1",
    "DataProviderSignalSelector2",
    "DataProviderSignalSelector3",
    "DateRange",
    "DateRangeSupport",
    "DatetimeRange",
    "DayOfWeek",
    "DaypartTarget",
    "DeclaredBy",
    "DegreeType",
    "DeletePropertyListRequest",
    "DeletePropertyListResponse",
    "DeliverTo",
    "DeliverTo1",
    "DeliveryForecast",
    "DeliveryMeasurement",
    "DeliveryMetrics",
    "DeliveryMode",
    "DeliveryStatus",
    "DeliveryType",
    "DemographicSystem",
    "Deployment",
    "Deployment1",
    "Deployment2",
    "Destination",
    "Destination1",
    "Destination2",
    "DestinationItem",
    "DestinationType",
    "DevicePlatform",
    "DeviceType",
    "DigitalSourceType",
    "DimensionUnit",
    "Dimensions",
    "Dimensions1",
    "Disclaimer",
    "Disclosure",
    "DisclosurePosition",
    "DistanceUnit",
    "Domain",
    "DoohMetrics",
    "Duration",
    "EducationItem",
    "Embedding",
    "EmploymentType",
    "Endpoint",
    "Error",
    "ErrorCode",
    "Event",
    "EventCustomData",
    "EventSource",
    "EventType",
    "Execution",
    "ExperienceLevel",
    "ExtensionObject",
    "ExtensionsSupportedItem",
    "Fail",
    "Feature",
    "FeatureRequirement",
    "Features",
    "FeedFormat",
    "FeedbackSource",
    "Field1",
    "FieldModel",
    "FlatRatePricingOption",
    "FlightItem",
    "FollowUp",
    "Fonts",
    "ForecastMethod",
    "ForecastPoint",
    "ForecastRange",
    "ForecastRangeUnit",
    "ForecastableMetric",
    "Format",
    "FormatCard",
    "FormatCardDetailed",
    "FormatCategory",
    "FormatId",
    "FormatIdParameter",
    "FrameRate",
    "FrameRateType",
    "FrequencyCap",
    "FrequencyCap1",
    "FrequencyCap2",
    "FrequencyCap3",
    "FrequencyCapScope",
    "FuelType",
    "GenerationContext",
    "Geo",
    "GeoCountriesExcludeItem",
    "GeoCountry",
    "GeoMetro",
    "GeoMetros",
    "GeoMetrosExcludeItem",
    "GeoPostalArea",
    "GeoPostalAreas",
    "GeoPostalAreasExcludeItem",
    "GeoProximity",
    "GeoProximity2",
    "GeoProximity3",
    "GeoRegion",
    "GeoRegionsExcludeItem",
    "GeoTargets",
    "GeographicBreakdownSupport",
    "GeographicTargetingLevel",
    "Geometry",
    "Geometry1",
    "Geometry2",
    "Geometry4",
    "Geometry5",
    "GetAccountFinancialsRequest",
    "GetAccountFinancialsResponse",
    "GetAccountFinancialsResponse1",
    "GetAccountFinancialsResponse2",
    "GetAdcpCapabilitiesRequest",
    "GetAdcpCapabilitiesResponse",
    "GetContentStandardsRequest",
    "GetContentStandardsResponse",
    "GetContentStandardsResponse1",
    "GetContentStandardsResponse2",
    "GetCreativeDeliveryRequest",
    "GetCreativeDeliveryRequest1",
    "GetCreativeDeliveryRequest2",
    "GetCreativeDeliveryRequest3",
    "GetCreativeDeliveryResponse",
    "GetCreativeFeaturesRequest",
    "GetCreativeFeaturesResponse",
    "GetCreativeFeaturesResponse1",
    "GetCreativeFeaturesResponse2",
    "GetMediaBuyArtifactsRequest",
    "GetMediaBuyArtifactsResponse",
    "GetMediaBuyArtifactsResponse1",
    "GetMediaBuyArtifactsResponse2",
    "GetMediaBuyDeliveryRequest",
    "GetMediaBuyDeliveryResponse",
    "GetMediaBuysRequest",
    "GetMediaBuysResponse",
    "GetProductsInputRequired",
    "GetProductsRequest",
    "GetProductsRequest1",
    "GetProductsRequest2",
    "GetProductsRequest3",
    "GetProductsResponse",
    "GetProductsSubmitted",
    "GetProductsWorking",
    "GetPropertyListRequest",
    "GetPropertyListResponse",
    "GetSignalsRequest",
    "GetSignalsRequest1",
    "GetSignalsRequest2",
    "GetSignalsResponse",
    "GopType",
    "Governance",
    "Gtin",
    "Handoff",
    "HdrFormat",
    "HistoryEntryType",
    "HotelItem",
    "House",
    "HtmlAsset",
    "HtmlAssetRequirements",
    "HttpMethod",
    "HumanOversight",
    "Identifier",
    "Identifiers",
    "IfNotCovered",
    "ImageAsset",
    "ImageAssetRequirements",
    "Input",
    "Input2",
    "Input4",
    "Intent",
    "Invoice",
    "ItemIssue",
    "JavascriptAsset",
    "JavascriptAssetRequirements",
    "JavascriptModuleType",
    "JobItem",
    "Jurisdiction",
    "KellerType",
    "KeywordTarget",
    "KeywordTargets",
    "KeywordTargetsAddItem",
    "KeywordTargetsAddItem1",
    "KeywordTargetsRemoveItem",
    "KeywordTargetsRemoveItem1",
    "LandingPageRequirement",
    "LanguageItem",
    "LastTopUp",
    "Level",
    "ListAccountsRequest",
    "ListAccountsResponse",
    "ListAuthorizedPropertiesRequest",
    "ListAuthorizedPropertiesResponse",
    "ListContentStandardsRequest",
    "ListContentStandardsResponse",
    "ListContentStandardsResponse1",
    "ListContentStandardsResponse2",
    "ListCreativeFormatsRequest",
    "ListCreativeFormatsRequestCreativeAgent",
    "ListCreativeFormatsResponse",
    "ListCreativeFormatsResponseCreativeAgent",
    "ListCreativesRequest",
    "ListCreativesResponse",
    "ListPropertyListsRequest",
    "ListPropertyListsResponse",
    "ListingType",
    "LocalVerdict",
    "LocalizedName",
    "Location",
    "LogEventRequest",
    "LogEventResponse",
    "LogEventResponse1",
    "LogEventResponse2",
    "Logo",
    "MajorVersion",
    "ManagedBy",
    "MarkdownAsset",
    "MarkdownAssetRequirements",
    "MarkdownFlavor",
    "MatchType",
    "MatchedGtin",
    "MatchingLatencyHours",
    "MatchingProduct",
    "McpWebhookPayload",
    "Measurement",
    "MeasurementPeriod",
    "MediaBuy",
    "MediaBuyDelivery",
    "MediaBuyFeatures",
    "MediaBuyPackage",
    "MediaBuyStatus",
    "MediaChannel",
    "Messaging",
    "Metadata",
    "Method",
    "Metric",
    "MetricOptimization",
    "MetricType",
    "Metrics",
    "Metro",
    "MetroAreaSystem",
    "Mileage",
    "Modalities",
    "Modality",
    "ModuleType",
    "MoovAtomPosition",
    "MraidVersion",
    "NegativeKeyword",
    "NegativeKeywords",
    "NegativeKeywordsAddItem",
    "NegativeKeywordsAddItem1",
    "NegativeKeywordsRemoveItem",
    "NegativeKeywordsRemoveItem1",
    "NotificationType",
    "Objective",
    "Offering",
    "OfferingAssetConstraint",
    "OfferingAssetGroup",
    "OptimizationGoal",
    "OptimizationGoal1",
    "OptimizationGoal2",
    "Orientation",
    "Origin",
    "OutcomeMeasurement",
    "Overlay",
    "Pacing",
    "PackageRequest",
    "PackageStatus",
    "PackageUpdate",
    "PackageUpdate1",
    "PackageUpdate2",
    "Pagination",
    "PaginationRequest",
    "PaginationResponse",
    "Parameters",
    "PartialFailure",
    "Pass",
    "PaymentStatus",
    "Performance",
    "PerformanceFeedback",
    "Period",
    "Placement",
    "Portfolio",
    "PostalArea",
    "PostalCodeSystem",
    "Preferred",
    "Preview",
    "Preview1",
    "Preview2",
    "Preview3",
    "PreviewCreativeRequest",
    "PreviewCreativeRequest1",
    "PreviewCreativeRequest2",
    "PreviewCreativeRequest3",
    "PreviewCreativeResponse",
    "PreviewCreativeResponse1",
    "PreviewCreativeResponse2",
    "PreviewCreativeResponse3",
    "PreviewOutputFormat",
    "PreviewRender",
    "PreviewRender1",
    "PreviewRender2",
    "PreviewRender3",
    "Price",
    "PriceGuidance",
    "Pricing",
    "PricingModel",
    "PricingOption",
    "PrimaryCountry",
    "PrivacyPolicyAcknowledged",
    "Product",
    "ProductAllocation",
    "ProductCard",
    "ProductCardDetailed",
    "ProductCatalog",
    "ProductFilters",
    "PromotedOfferings",
    "PromotedOfferingsAssetRequirements",
    "PromotedOfferingsRequirement",
    "PromotedProducts",
    "Property",
    "PropertyError",
    "PropertyFeature",
    "PropertyFeatureDefinition",
    "PropertyId",
    "PropertyIdentifierTypes",
    "PropertyList",
    "PropertyListChangedWebhook",
    "PropertyListFilters",
    "PropertyListReference",
    "PropertyTag",
    "PropertyType",
    "Proposal",
    "Protocol",
    "ProtocolEnvelope",
    "ProtocolResponse",
    "Provenance",
    "ProvidePerformanceFeedbackRequest",
    "ProvidePerformanceFeedbackRequest1",
    "ProvidePerformanceFeedbackRequest2",
    "ProvidePerformanceFeedbackResponse",
    "ProvidePerformanceFeedbackResponse1",
    "ProvidePerformanceFeedbackResponse2",
    "Provider",
    "PublisherDomain",
    "PublisherIdentifierTypes",
    "PublisherPropertySelector",
    "PublisherPropertySelector1",
    "PublisherPropertySelector2",
    "PublisherPropertySelector3",
    "PushNotificationConfig",
    "QuartileData",
    "QuerySummary",
    "Radius",
    "Range",
    "ReachUnit",
    "RealEstateItem",
    "Reason",
    "Record",
    "Recovery",
    "ReferenceAsset",
    "Refine",
    "Refine1",
    "Refine2",
    "RefinementAppliedItem",
    "Region",
    "Renders",
    "Renders1",
    "ReportUsageRequest",
    "ReportUsageResponse",
    "Reporting",
    "ReportingCapabilities",
    "ReportingDimensions",
    "ReportingFrequency",
    "ReportingPeriod",
    "ReportingWebhook",
    "Request",
    "RequiredDisclosure",
    "RequiredGeoTargetingItem",
    "Response",
    "Response1",
    "Responsive",
    "Result",
    "Results",
    "Results1",
    "Role",
    "Salary",
    "SampleRate",
    "Sampling",
    "SamplingInfo",
    "Sandbox",
    "ScalarBinding",
    "ScanType",
    "Scope",
    "Security",
    "SelectionMode",
    "SessionStatus",
    "Setup",
    "ShippingAddress",
    "SiCapabilities",
    "SiGetOfferingRequest",
    "SiGetOfferingResponse",
    "SiIdentity",
    "SiInitiateSessionRequest",
    "SiInitiateSessionResponse",
    "SiSendMessageRequest",
    "SiSendMessageRequest1",
    "SiSendMessageRequest2",
    "SiSendMessageResponse",
    "SiTerminateSessionRequest",
    "SiTerminateSessionResponse",
    "SiUiElement",
    "Signal",
    "SignalCatalogType",
    "SignalDefinition",
    "SignalFilters",
    "SignalId",
    "SignalId2",
    "SignalId3",
    "SignalPricing",
    "SignalPricing1",
    "SignalPricing2",
    "SignalPricing3",
    "SignalPricingOption",
    "SignalPricingOption1",
    "SignalPricingOption2",
    "SignalPricingOption3",
    "SignalPricingOption4",
    "SignalPricingOption5",
    "SignalPricingOption6",
    "SignalPricingOption7",
    "SignalSource",
    "SignalTag",
    "SignalTags",
    "SignalTargeting",
    "SignalTargeting1",
    "SignalTargeting2",
    "SignalTargeting3",
    "SignalValueType",
    "Signals",
    "Snapshot",
    "SnapshotUnavailableReason",
    "SnippetType",
    "Sort",
    "SortApplied",
    "SortDirection",
    "SortMetric",
    "Spend",
    "SponsoredIntelligence",
    "Standard",
    "StandardEnum",
    "StartTiming",
    "Status",
    "StatusFilter",
    "StatusSummary",
    "Store",
    "StoreCatchment",
    "StoreItem",
    "SubAsset",
    "SubAsset1",
    "SubAsset2",
    "Summary",
    "SupportedBillingEnum",
    "SupportedIdentifierType",
    "SupportedMatchType",
    "SupportedMetric",
    "SupportedProtocol",
    "SupportedTarget",
    "SupportedTarget1",
    "SupportedViewDuration",
    "SyncAccountsRequest",
    "SyncAccountsResponse",
    "SyncAccountsResponse1",
    "SyncAccountsResponse2",
    "SyncAudiencesRequest",
    "SyncAudiencesResponse",
    "SyncAudiencesResponse1",
    "SyncAudiencesResponse2",
    "SyncCatalogsInputRequired",
    "SyncCatalogsRequest",
    "SyncCatalogsResponse",
    "SyncCatalogsResponse1",
    "SyncCatalogsResponse2",
    "SyncCatalogsSubmitted",
    "SyncCatalogsWorking",
    "SyncCreativesInputRequired",
    "SyncCreativesRequest",
    "SyncCreativesResponse",
    "SyncCreativesResponse1",
    "SyncCreativesResponse2",
    "SyncCreativesSubmitted",
    "SyncCreativesWorking",
    "SyncEventSourcesRequest",
    "SyncEventSourcesResponse",
    "SyncEventSourcesResponse1",
    "SyncEventSourcesResponse2",
    "Tag",
    "Tags",
    "Target",
    "Target1",
    "Target2",
    "Target3",
    "Target4",
    "TargetFrequency",
    "TargetFrequency1",
    "Targeting",
    "TargetingOverlay",
    "TaskStatus",
    "TaskType",
    "TerminationContext",
    "TextAsset",
    "TextAssetRequirements",
    "TimeBasedPricingOption",
    "TimeRange",
    "TimeUnit",
    "Tone",
    "TotalBudget",
    "TotalBudgetGuidance",
    "Totals",
    "Trademark",
    "TransactionIntent",
    "TranscriptSource",
    "TranscriptSource1",
    "Transform",
    "Transmission",
    "Transport",
    "TransportMode",
    "TravelTime",
    "TravelTime1",
    "TravelTime2",
    "TravelTime4",
    "TravelTime5",
    "Type",
    "Uid",
    "UidType",
    "Unit",
    "UniversalMacro",
    "UpdateContentStandardsRequest",
    "UpdateContentStandardsResponse",
    "UpdateContentStandardsResponse1",
    "UpdateContentStandardsResponse2",
    "UpdateFrequency",
    "UpdateMediaBuyInputRequired",
    "UpdateMediaBuyRequest",
    "UpdateMediaBuyRequest1",
    "UpdateMediaBuyRequest2",
    "UpdateMediaBuyResponse",
    "UpdateMediaBuyResponse1",
    "UpdateMediaBuyResponse2",
    "UpdateMediaBuySubmitted",
    "UpdateMediaBuyWorking",
    "UpdatePropertyListRequest",
    "UpdatePropertyListResponse",
    "UrlAsset",
    "UrlAssetRequirements",
    "UrlAssetType",
    "UsageItem",
    "User",
    "UserMatch",
    "UserMatch1",
    "UserMatch2",
    "UserMatch3",
    "UserMatch4",
    "UserMatch5",
    "ValidateContentDeliveryRequest",
    "ValidateContentDeliveryResponse",
    "ValidateContentDeliveryResponse1",
    "ValidateContentDeliveryResponse2",
    "ValidationMode",
    "Variant",
    "VastAsset",
    "VastAsset1",
    "VastAsset2",
    "VastAssetRequirements",
    "VastTrackingEvent",
    "VastVersion",
    "VcpmPricingOption",
    "VehicleItem",
    "VenueBreakdownItem",
    "Verdict",
    "VerificationItem",
    "Video",
    "VideoAsset",
    "VideoAssetRequirements",
    "VideoBitDepth",
    "ViewThreshold",
    "ViewThreshold1",
    "Viewability",
    "Visual",
    "Voice",
    "WcagLevel",
    "WebhookAsset",
    "WebhookAssetRequirements",
    "WebhookResponseType",
    "WebhookSecurityMethod",
    "_AudienceFromGetMediaBuyDeliveryRequest",
    "_AudienceFromSyncAudiencesRequest",
    "_AudienceFromSyncAudiencesResponse",
    "_DeliveryStatusFromGetMediaBuyDeliveryResponse",
    "_PackageFromPackage",
]


# Rebuild models with forward references
# This must happen AFTER all imports to resolve forward reference chains

# Import individual modules needed for rebuilding
from adcp.types import generated_poc  # noqa: F401

# Rebuild models that reference other models via forward refs
CreativeManifest.model_rebuild()
PreviewCreativeRequest1.model_rebuild()
PreviewCreativeRequest2.model_rebuild()
PreviewCreativeRequest.model_rebuild()
