# generated by datamodel-codegen:
#   filename:  property/delete_property_list_response.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import ext as ext_1


class DeletePropertyListResponse(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    deleted: Annotated[bool, Field(description='Whether the list was successfully deleted')]
    ext: ext_1.ExtensionObject | None = None
    list_id: Annotated[str, Field(description='ID of the deleted list')]
