# generated by datamodel-codegen:
#   filename:  core/requirements/vast_asset_requirements.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum
from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class VastVersion(Enum):
    field_2_0 = '2.0'
    field_3_0 = '3.0'
    field_4_0 = '4.0'
    field_4_1 = '4.1'
    field_4_2 = '4.2'


class VastAssetRequirements(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    vast_version: Annotated[VastVersion | None, Field(description='Required VAST version')] = None
