# generated by datamodel-codegen:
#   filename:  core/forecast_range.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class ForecastRange(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    high: Annotated[
        float | None, Field(description='Optimistic (high-end) forecast value', ge=0.0)
    ] = None
    low: Annotated[
        float | None, Field(description='Conservative (low-end) forecast value', ge=0.0)
    ] = None
    mid: Annotated[float, Field(description='Expected (most likely) forecast value', ge=0.0)]
