# generated by datamodel-codegen:
#   filename:  core/date_range.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from datetime import date as date_aliased
from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class DateRange(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    end: Annotated[date_aliased, Field(description='End date (inclusive), ISO 8601')]
    start: Annotated[date_aliased, Field(description='Start date (inclusive), ISO 8601')]
