# generated by datamodel-codegen:
#   filename:  core/start_timing.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated, Literal

from pydantic import AwareDatetime, Field, RootModel


class StartTiming(RootModel[Literal['asap'] | AwareDatetime]):
    root: Annotated[
        Literal['asap'] | AwareDatetime,
        Field(
            description="Campaign start timing: 'asap' or ISO 8601 date-time", title='Start Timing'
        ),
    ]
