# generated by datamodel-codegen:
#   filename:  enums/webhook_security_method.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class WebhookSecurityMethod(Enum):
    hmac_sha256 = 'hmac_sha256'
    api_key = 'api_key'
    none = 'none'
