# generated by datamodel-codegen:
#   filename:  enums/http_method.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class HttpMethod(Enum):
    GET = 'GET'
    POST = 'POST'
