# generated by datamodel-codegen:
#   filename:  core/requirements/daast_asset_requirements.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated, Literal

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class DaastAssetRequirements(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    daast_version: Annotated[
        Literal['1.0'] | None,
        Field(description='Required DAAST version. DAAST 1.0 is the current IAB standard.'),
    ] = None
