# generated by datamodel-codegen:
#   filename:  enums/available_metric.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class AvailableMetric(Enum):
    impressions = 'impressions'
    spend = 'spend'
    clicks = 'clicks'
    ctr = 'ctr'
    video_completions = 'video_completions'
    completion_rate = 'completion_rate'
    conversions = 'conversions'
    conversion_value = 'conversion_value'
    roas = 'roas'
    cost_per_acquisition = 'cost_per_acquisition'
    new_to_brand_rate = 'new_to_brand_rate'
    viewability = 'viewability'
    engagement_rate = 'engagement_rate'
    views = 'views'
    completed_views = 'completed_views'
    leads = 'leads'
    reach = 'reach'
    frequency = 'frequency'
    grps = 'grps'
    quartile_data = 'quartile_data'
    dooh_metrics = 'dooh_metrics'
    cost_per_click = 'cost_per_click'
