# generated by datamodel-codegen:
#   filename:  enums/creative_sort_field.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class CreativeSortField(Enum):
    created_date = 'created_date'
    updated_date = 'updated_date'
    name = 'name'
    status = 'status'
    assignment_count = 'assignment_count'
    performance_score = 'performance_score'
