# generated by datamodel-codegen:
#   filename:  content_standards/list_content_standards_response.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import Field, RootModel

from ..core import context as context_1
from ..core import error
from ..core import ext as ext_1
from ..core import pagination_response
from . import content_standards


class ListContentStandardsResponse2(AdCPBaseModel):
    context: context_1.ContextObject | None = None
    errors: list[error.Error]
    ext: ext_1.ExtensionObject | None = None


class ListContentStandardsResponse1(AdCPBaseModel):
    context: context_1.ContextObject | None = None
    ext: ext_1.ExtensionObject | None = None
    pagination: pagination_response.PaginationResponse | None = None
    standards: Annotated[
        list[content_standards.ContentStandards],
        Field(description='Array of content standards configurations matching the filter criteria'),
    ]


class ListContentStandardsResponse(
    RootModel[ListContentStandardsResponse1 | ListContentStandardsResponse2]
):
    root: Annotated[
        ListContentStandardsResponse1 | ListContentStandardsResponse2,
        Field(
            description='Response payload with list of content standards configurations',
            title='List Content Standards Response',
        ),
    ]
