# generated by datamodel-codegen:
#   filename:  enums/co_branding_requirement.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class CoBrandingRequirement(Enum):
    required = 'required'
    optional = 'optional'
    none = 'none'
