# generated by datamodel-codegen:
#   filename:  content_standards/get_content_standards_response.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import Field, RootModel

from ..core import context as context_1
from ..core import error
from ..core import ext as ext_1
from .content_standards import ContentStandards


class GetContentStandardsResponse2(AdCPBaseModel):
    context: context_1.ContextObject | None = None
    errors: list[error.Error]
    ext: ext_1.ExtensionObject | None = None


class GetContentStandardsResponse1(ContentStandards):
    context: context_1.ContextObject | None = None


class GetContentStandardsResponse(
    RootModel[GetContentStandardsResponse1 | GetContentStandardsResponse2]
):
    root: Annotated[
        GetContentStandardsResponse1 | GetContentStandardsResponse2,
        Field(
            description='Response payload with content safety policies',
            title='Get Content Standards Response',
        ),
    ]
