# generated by datamodel-codegen:
#   filename:  core/requirements/webhook_asset_requirements.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum
from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class Method(Enum):
    GET = 'GET'
    POST = 'POST'


class WebhookAssetRequirements(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    methods: Annotated[list[Method] | None, Field(description='Allowed HTTP methods')] = None
