# generated by datamodel-codegen:
#   filename:  enums/sort_metric.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from enum import Enum


class SortMetric(Enum):
    impressions = 'impressions'
    spend = 'spend'
    clicks = 'clicks'
    ctr = 'ctr'
    views = 'views'
    completed_views = 'completed_views'
    completion_rate = 'completion_rate'
    conversions = 'conversions'
    conversion_value = 'conversion_value'
    roas = 'roas'
    cost_per_acquisition = 'cost_per_acquisition'
    new_to_brand_rate = 'new_to_brand_rate'
    leads = 'leads'
    grps = 'grps'
    reach = 'reach'
    frequency = 'frequency'
    engagements = 'engagements'
    follows = 'follows'
    saves = 'saves'
    profile_visits = 'profile_visits'
    engagement_rate = 'engagement_rate'
    cost_per_click = 'cost_per_click'
