# generated by datamodel-codegen:
#   filename:  enums/vast_tracking_event.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class VastTrackingEvent(Enum):
    start = 'start'
    firstQuartile = 'firstQuartile'
    midpoint = 'midpoint'
    thirdQuartile = 'thirdQuartile'
    complete = 'complete'
    impression = 'impression'
    click = 'click'
    pause = 'pause'
    resume = 'resume'
    skip = 'skip'
    mute = 'mute'
    unmute = 'unmute'
    fullscreen = 'fullscreen'
    exitFullscreen = 'exitFullscreen'
    playerExpand = 'playerExpand'
    playerCollapse = 'playerCollapse'
