# generated by datamodel-codegen:
#   filename:  enums/attribution_model.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class AttributionModel(Enum):
    last_touch = 'last_touch'
    first_touch = 'first_touch'
    linear = 'linear'
    time_decay = 'time_decay'
    data_driven = 'data_driven'
