# generated by datamodel-codegen:
#   filename:  property/list_property_lists_response.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import ext as ext_1
from ..core import pagination_response
from . import property_list


class ListPropertyListsResponse(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    ext: ext_1.ExtensionObject | None = None
    lists: Annotated[
        list[property_list.PropertyList],
        Field(description='Array of property lists (metadata only, not resolved properties)'),
    ]
    pagination: pagination_response.PaginationResponse | None = None
